"""
PVfit: Sample data measurement for example spectral corrections.

Copyright 2023 Intelligent Measurement Systems LLC
"""

import numpy

import pvfit.measurement.spectral_correction.computation as computation

# ASTM G173 Global. See https://rredc.nrel.gov/solar//spectra/am1.5/
lambda_G173_global_tilt_nm = numpy.array(
    [
        280,
        280.5,
        281,
        281.5,
        282,
        282.5,
        283,
        283.5,
        284,
        284.5,
        285,
        285.5,
        286,
        286.5,
        287,
        287.5,
        288,
        288.5,
        289,
        289.5,
        290,
        290.5,
        291,
        291.5,
        292,
        292.5,
        293,
        293.5,
        294,
        294.5,
        295,
        295.5,
        296,
        296.5,
        297,
        297.5,
        298,
        298.5,
        299,
        299.5,
        300,
        300.5,
        301,
        301.5,
        302,
        302.5,
        303,
        303.5,
        304,
        304.5,
        305,
        305.5,
        306,
        306.5,
        307,
        307.5,
        308,
        308.5,
        309,
        309.5,
        310,
        310.5,
        311,
        311.5,
        312,
        312.5,
        313,
        313.5,
        314,
        314.5,
        315,
        315.5,
        316,
        316.5,
        317,
        317.5,
        318,
        318.5,
        319,
        319.5,
        320,
        320.5,
        321,
        321.5,
        322,
        322.5,
        323,
        323.5,
        324,
        324.5,
        325,
        325.5,
        326,
        326.5,
        327,
        327.5,
        328,
        328.5,
        329,
        329.5,
        330,
        330.5,
        331,
        331.5,
        332,
        332.5,
        333,
        333.5,
        334,
        334.5,
        335,
        335.5,
        336,
        336.5,
        337,
        337.5,
        338,
        338.5,
        339,
        339.5,
        340,
        340.5,
        341,
        341.5,
        342,
        342.5,
        343,
        343.5,
        344,
        344.5,
        345,
        345.5,
        346,
        346.5,
        347,
        347.5,
        348,
        348.5,
        349,
        349.5,
        350,
        350.5,
        351,
        351.5,
        352,
        352.5,
        353,
        353.5,
        354,
        354.5,
        355,
        355.5,
        356,
        356.5,
        357,
        357.5,
        358,
        358.5,
        359,
        359.5,
        360,
        360.5,
        361,
        361.5,
        362,
        362.5,
        363,
        363.5,
        364,
        364.5,
        365,
        365.5,
        366,
        366.5,
        367,
        367.5,
        368,
        368.5,
        369,
        369.5,
        370,
        370.5,
        371,
        371.5,
        372,
        372.5,
        373,
        373.5,
        374,
        374.5,
        375,
        375.5,
        376,
        376.5,
        377,
        377.5,
        378,
        378.5,
        379,
        379.5,
        380,
        380.5,
        381,
        381.5,
        382,
        382.5,
        383,
        383.5,
        384,
        384.5,
        385,
        385.5,
        386,
        386.5,
        387,
        387.5,
        388,
        388.5,
        389,
        389.5,
        390,
        390.5,
        391,
        391.5,
        392,
        392.5,
        393,
        393.5,
        394,
        394.5,
        395,
        395.5,
        396,
        396.5,
        397,
        397.5,
        398,
        398.5,
        399,
        399.5,
        400,
        401,
        402,
        403,
        404,
        405,
        406,
        407,
        408,
        409,
        410,
        411,
        412,
        413,
        414,
        415,
        416,
        417,
        418,
        419,
        420,
        421,
        422,
        423,
        424,
        425,
        426,
        427,
        428,
        429,
        430,
        431,
        432,
        433,
        434,
        435,
        436,
        437,
        438,
        439,
        440,
        441,
        442,
        443,
        444,
        445,
        446,
        447,
        448,
        449,
        450,
        451,
        452,
        453,
        454,
        455,
        456,
        457,
        458,
        459,
        460,
        461,
        462,
        463,
        464,
        465,
        466,
        467,
        468,
        469,
        470,
        471,
        472,
        473,
        474,
        475,
        476,
        477,
        478,
        479,
        480,
        481,
        482,
        483,
        484,
        485,
        486,
        487,
        488,
        489,
        490,
        491,
        492,
        493,
        494,
        495,
        496,
        497,
        498,
        499,
        500,
        501,
        502,
        503,
        504,
        505,
        506,
        507,
        508,
        509,
        510,
        511,
        512,
        513,
        514,
        515,
        516,
        517,
        518,
        519,
        520,
        521,
        522,
        523,
        524,
        525,
        526,
        527,
        528,
        529,
        530,
        531,
        532,
        533,
        534,
        535,
        536,
        537,
        538,
        539,
        540,
        541,
        542,
        543,
        544,
        545,
        546,
        547,
        548,
        549,
        550,
        551,
        552,
        553,
        554,
        555,
        556,
        557,
        558,
        559,
        560,
        561,
        562,
        563,
        564,
        565,
        566,
        567,
        568,
        569,
        570,
        571,
        572,
        573,
        574,
        575,
        576,
        577,
        578,
        579,
        580,
        581,
        582,
        583,
        584,
        585,
        586,
        587,
        588,
        589,
        590,
        591,
        592,
        593,
        594,
        595,
        596,
        597,
        598,
        599,
        600,
        601,
        602,
        603,
        604,
        605,
        606,
        607,
        608,
        609,
        610,
        611,
        612,
        613,
        614,
        615,
        616,
        617,
        618,
        619,
        620,
        621,
        622,
        623,
        624,
        625,
        626,
        627,
        628,
        629,
        630,
        631,
        632,
        633,
        634,
        635,
        636,
        637,
        638,
        639,
        640,
        641,
        642,
        643,
        644,
        645,
        646,
        647,
        648,
        649,
        650,
        651,
        652,
        653,
        654,
        655,
        656,
        657,
        658,
        659,
        660,
        661,
        662,
        663,
        664,
        665,
        666,
        667,
        668,
        669,
        670,
        671,
        672,
        673,
        674,
        675,
        676,
        677,
        678,
        679,
        680,
        681,
        682,
        683,
        684,
        685,
        686,
        687,
        688,
        689,
        690,
        691,
        692,
        693,
        694,
        695,
        696,
        697,
        698,
        699,
        700,
        701,
        702,
        703,
        704,
        705,
        706,
        707,
        708,
        709,
        710,
        711,
        712,
        713,
        714,
        715,
        716,
        717,
        718,
        719,
        720,
        721,
        722,
        723,
        724,
        725,
        726,
        727,
        728,
        729,
        730,
        731,
        732,
        733,
        734,
        735,
        736,
        737,
        738,
        739,
        740,
        741,
        742,
        743,
        744,
        745,
        746,
        747,
        748,
        749,
        750,
        751,
        752,
        753,
        754,
        755,
        756,
        757,
        758,
        759,
        760,
        761,
        762,
        763,
        764,
        765,
        766,
        767,
        768,
        769,
        770,
        771,
        772,
        773,
        774,
        775,
        776,
        777,
        778,
        779,
        780,
        781,
        782,
        783,
        784,
        785,
        786,
        787,
        788,
        789,
        790,
        791,
        792,
        793,
        794,
        795,
        796,
        797,
        798,
        799,
        800,
        801,
        802,
        803,
        804,
        805,
        806,
        807,
        808,
        809,
        810,
        811,
        812,
        813,
        814,
        815,
        816,
        817,
        818,
        819,
        820,
        821,
        822,
        823,
        824,
        825,
        826,
        827,
        828,
        829,
        830,
        831,
        832,
        833,
        834,
        835,
        836,
        837,
        838,
        839,
        840,
        841,
        842,
        843,
        844,
        845,
        846,
        847,
        848,
        849,
        850,
        851,
        852,
        853,
        854,
        855,
        856,
        857,
        858,
        859,
        860,
        861,
        862,
        863,
        864,
        865,
        866,
        867,
        868,
        869,
        870,
        871,
        872,
        873,
        874,
        875,
        876,
        877,
        878,
        879,
        880,
        881,
        882,
        883,
        884,
        885,
        886,
        887,
        888,
        889,
        890,
        891,
        892,
        893,
        894,
        895,
        896,
        897,
        898,
        899,
        900,
        901,
        902,
        903,
        904,
        905,
        906,
        907,
        908,
        909,
        910,
        911,
        912,
        913,
        914,
        915,
        916,
        917,
        918,
        919,
        920,
        921,
        922,
        923,
        924,
        925,
        926,
        927,
        928,
        929,
        930,
        931,
        932,
        933,
        934,
        935,
        936,
        937,
        938,
        939,
        940,
        941,
        942,
        943,
        944,
        945,
        946,
        947,
        948,
        949,
        950,
        951,
        952,
        953,
        954,
        955,
        956,
        957,
        958,
        959,
        960,
        961,
        962,
        963,
        964,
        965,
        966,
        967,
        968,
        969,
        970,
        971,
        972,
        973,
        974,
        975,
        976,
        977,
        978,
        979,
        980,
        981,
        982,
        983,
        984,
        985,
        986,
        987,
        988,
        989,
        990,
        991,
        992,
        993,
        994,
        995,
        996,
        997,
        998,
        999,
        1000,
        1001,
        1002,
        1003,
        1004,
        1005,
        1006,
        1007,
        1008,
        1009,
        1010,
        1011,
        1012,
        1013,
        1014,
        1015,
        1016,
        1017,
        1018,
        1019,
        1020,
        1021,
        1022,
        1023,
        1024,
        1025,
        1026,
        1027,
        1028,
        1029,
        1030,
        1031,
        1032,
        1033,
        1034,
        1035,
        1036,
        1037,
        1038,
        1039,
        1040,
        1041,
        1042,
        1043,
        1044,
        1045,
        1046,
        1047,
        1048,
        1049,
        1050,
        1051,
        1052,
        1053,
        1054,
        1055,
        1056,
        1057,
        1058,
        1059,
        1060,
        1061,
        1062,
        1063,
        1064,
        1065,
        1066,
        1067,
        1068,
        1069,
        1070,
        1071,
        1072,
        1073,
        1074,
        1075,
        1076,
        1077,
        1078,
        1079,
        1080,
        1081,
        1082,
        1083,
        1084,
        1085,
        1086,
        1087,
        1088,
        1089,
        1090,
        1091,
        1092,
        1093,
        1094,
        1095,
        1096,
        1097,
        1098,
        1099,
        1100,
        1101,
        1102,
        1103,
        1104,
        1105,
        1106,
        1107,
        1108,
        1109,
        1110,
        1111,
        1112,
        1113,
        1114,
        1115,
        1116,
        1117,
        1118,
        1119,
        1120,
        1121,
        1122,
        1123,
        1124,
        1125,
        1126,
        1127,
        1128,
        1129,
        1130,
        1131,
        1132,
        1133,
        1134,
        1135,
        1136,
        1137,
        1138,
        1139,
        1140,
        1141,
        1142,
        1143,
        1144,
        1145,
        1146,
        1147,
        1148,
        1149,
        1150,
        1151,
        1152,
        1153,
        1154,
        1155,
        1156,
        1157,
        1158,
        1159,
        1160,
        1161,
        1162,
        1163,
        1164,
        1165,
        1166,
        1167,
        1168,
        1169,
        1170,
        1171,
        1172,
        1173,
        1174,
        1175,
        1176,
        1177,
        1178,
        1179,
        1180,
        1181,
        1182,
        1183,
        1184,
        1185,
        1186,
        1187,
        1188,
        1189,
        1190,
        1191,
        1192,
        1193,
        1194,
        1195,
        1196,
        1197,
        1198,
        1199,
        1200,
        1201,
        1202,
        1203,
        1204,
        1205,
        1206,
        1207,
        1208,
        1209,
        1210,
        1211,
        1212,
        1213,
        1214,
        1215,
        1216,
        1217,
        1218,
        1219,
        1220,
        1221,
        1222,
        1223,
        1224,
        1225,
        1226,
        1227,
        1228,
        1229,
        1230,
        1231,
        1232,
        1233,
        1234,
        1235,
        1236,
        1237,
        1238,
        1239,
        1240,
        1241,
        1242,
        1243,
        1244,
        1245,
        1246,
        1247,
        1248,
        1249,
        1250,
        1251,
        1252,
        1253,
        1254,
        1255,
        1256,
        1257,
        1258,
        1259,
        1260,
        1261,
        1262,
        1263,
        1264,
        1265,
        1266,
        1267,
        1268,
        1269,
        1270,
        1271,
        1272,
        1273,
        1274,
        1275,
        1276,
        1277,
        1278,
        1279,
        1280,
        1281,
        1282,
        1283,
        1284,
        1285,
        1286,
        1287,
        1288,
        1289,
        1290,
        1291,
        1292,
        1293,
        1294,
        1295,
        1296,
        1297,
        1298,
        1299,
        1300,
        1301,
        1302,
        1303,
        1304,
        1305,
        1306,
        1307,
        1308,
        1309,
        1310,
        1311,
        1312,
        1313,
        1314,
        1315,
        1316,
        1317,
        1318,
        1319,
        1320,
        1321,
        1322,
        1323,
        1324,
        1325,
        1326,
        1327,
        1328,
        1329,
        1330,
        1331,
        1332,
        1333,
        1334,
        1335,
        1336,
        1337,
        1338,
        1339,
        1340,
        1341,
        1342,
        1343,
        1344,
        1345,
        1346,
        1347,
        1348,
        1349,
        1350,
        1351,
        1352,
        1353,
        1354,
        1355,
        1356,
        1357,
        1358,
        1359,
        1360,
        1361,
        1362,
        1363,
        1364,
        1365,
        1366,
        1367,
        1368,
        1369,
        1370,
        1371,
        1372,
        1373,
        1374,
        1375,
        1376,
        1377,
        1378,
        1379,
        1380,
        1381,
        1382,
        1383,
        1384,
        1385,
        1386,
        1387,
        1388,
        1389,
        1390,
        1391,
        1392,
        1393,
        1394,
        1395,
        1396,
        1397,
        1398,
        1399,
        1400,
        1401,
        1402,
        1403,
        1404,
        1405,
        1406,
        1407,
        1408,
        1409,
        1410,
        1411,
        1412,
        1413,
        1414,
        1415,
        1416,
        1417,
        1418,
        1419,
        1420,
        1421,
        1422,
        1423,
        1424,
        1425,
        1426,
        1427,
        1428,
        1429,
        1430,
        1431,
        1432,
        1433,
        1434,
        1435,
        1436,
        1437,
        1438,
        1439,
        1440,
        1441,
        1442,
        1443,
        1444,
        1445,
        1446,
        1447,
        1448,
        1449,
        1450,
        1451,
        1452,
        1453,
        1454,
        1455,
        1456,
        1457,
        1458,
        1459,
        1460,
        1461,
        1462,
        1463,
        1464,
        1465,
        1466,
        1467,
        1468,
        1469,
        1470,
        1471,
        1472,
        1473,
        1474,
        1475,
        1476,
        1477,
        1478,
        1479,
        1480,
        1481,
        1482,
        1483,
        1484,
        1485,
        1486,
        1487,
        1488,
        1489,
        1490,
        1491,
        1492,
        1493,
        1494,
        1495,
        1496,
        1497,
        1498,
        1499,
        1500,
        1501,
        1502,
        1503,
        1504,
        1505,
        1506,
        1507,
        1508,
        1509,
        1510,
        1511,
        1512,
        1513,
        1514,
        1515,
        1516,
        1517,
        1518,
        1519,
        1520,
        1521,
        1522,
        1523,
        1524,
        1525,
        1526,
        1527,
        1528,
        1529,
        1530,
        1531,
        1532,
        1533,
        1534,
        1535,
        1536,
        1537,
        1538,
        1539,
        1540,
        1541,
        1542,
        1543,
        1544,
        1545,
        1546,
        1547,
        1548,
        1549,
        1550,
        1551,
        1552,
        1553,
        1554,
        1555,
        1556,
        1557,
        1558,
        1559,
        1560,
        1561,
        1562,
        1563,
        1564,
        1565,
        1566,
        1567,
        1568,
        1569,
        1570,
        1571,
        1572,
        1573,
        1574,
        1575,
        1576,
        1577,
        1578,
        1579,
        1580,
        1581,
        1582,
        1583,
        1584,
        1585,
        1586,
        1587,
        1588,
        1589,
        1590,
        1591,
        1592,
        1593,
        1594,
        1595,
        1596,
        1597,
        1598,
        1599,
        1600,
        1601,
        1602,
        1603,
        1604,
        1605,
        1606,
        1607,
        1608,
        1609,
        1610,
        1611,
        1612,
        1613,
        1614,
        1615,
        1616,
        1617,
        1618,
        1619,
        1620,
        1621,
        1622,
        1623,
        1624,
        1625,
        1626,
        1627,
        1628,
        1629,
        1630,
        1631,
        1632,
        1633,
        1634,
        1635,
        1636,
        1637,
        1638,
        1639,
        1640,
        1641,
        1642,
        1643,
        1644,
        1645,
        1646,
        1647,
        1648,
        1649,
        1650,
        1651,
        1652,
        1653,
        1654,
        1655,
        1656,
        1657,
        1658,
        1659,
        1660,
        1661,
        1662,
        1663,
        1664,
        1665,
        1666,
        1667,
        1668,
        1669,
        1670,
        1671,
        1672,
        1673,
        1674,
        1675,
        1676,
        1677,
        1678,
        1679,
        1680,
        1681,
        1682,
        1683,
        1684,
        1685,
        1686,
        1687,
        1688,
        1689,
        1690,
        1691,
        1692,
        1693,
        1694,
        1695,
        1696,
        1697,
        1698,
        1699,
        1700,
        1702,
        1705,
        1710,
        1715,
        1720,
        1725,
        1730,
        1735,
        1740,
        1745,
        1750,
        1755,
        1760,
        1765,
        1770,
        1775,
        1780,
        1785,
        1790,
        1795,
        1800,
        1805,
        1810,
        1815,
        1820,
        1825,
        1830,
        1835,
        1840,
        1845,
        1850,
        1855,
        1860,
        1865,
        1870,
        1875,
        1880,
        1885,
        1890,
        1895,
        1900,
        1905,
        1910,
        1915,
        1920,
        1925,
        1930,
        1935,
        1940,
        1945,
        1950,
        1955,
        1960,
        1965,
        1970,
        1975,
        1980,
        1985,
        1990,
        1995,
        2000,
        2005,
        2010,
        2015,
        2020,
        2025,
        2030,
        2035,
        2040,
        2045,
        2050,
        2055,
        2060,
        2065,
        2070,
        2075,
        2080,
        2085,
        2090,
        2095,
        2100,
        2105,
        2110,
        2115,
        2120,
        2125,
        2130,
        2135,
        2140,
        2145,
        2150,
        2155,
        2160,
        2165,
        2170,
        2175,
        2180,
        2185,
        2190,
        2195,
        2200,
        2205,
        2210,
        2215,
        2220,
        2225,
        2230,
        2235,
        2240,
        2245,
        2250,
        2255,
        2260,
        2265,
        2270,
        2275,
        2280,
        2285,
        2290,
        2295,
        2300,
        2305,
        2310,
        2315,
        2320,
        2325,
        2330,
        2335,
        2340,
        2345,
        2350,
        2355,
        2360,
        2365,
        2370,
        2375,
        2380,
        2385,
        2390,
        2395,
        2400,
        2405,
        2410,
        2415,
        2420,
        2425,
        2430,
        2435,
        2440,
        2445,
        2450,
        2455,
        2460,
        2465,
        2470,
        2475,
        2480,
        2485,
        2490,
        2495,
        2500,
        2505,
        2510,
        2515,
        2520,
        2525,
        2530,
        2535,
        2540,
        2545,
        2550,
        2555,
        2560,
        2565,
        2570,
        2575,
        2580,
        2585,
        2590,
        2595,
        2600,
        2605,
        2610,
        2615,
        2620,
        2625,
        2630,
        2635,
        2640,
        2645,
        2650,
        2655,
        2660,
        2665,
        2670,
        2675,
        2680,
        2685,
        2690,
        2695,
        2700,
        2705,
        2710,
        2715,
        2720,
        2725,
        2730,
        2735,
        2740,
        2745,
        2750,
        2755,
        2760,
        2765,
        2770,
        2775,
        2780,
        2785,
        2790,
        2795,
        2800,
        2805,
        2810,
        2815,
        2820,
        2825,
        2830,
        2835,
        2840,
        2845,
        2850,
        2855,
        2860,
        2865,
        2870,
        2875,
        2880,
        2885,
        2890,
        2895,
        2900,
        2905,
        2910,
        2915,
        2920,
        2925,
        2930,
        2935,
        2940,
        2945,
        2950,
        2955,
        2960,
        2965,
        2970,
        2975,
        2980,
        2985,
        2990,
        2995,
        3000,
        3005,
        3010,
        3015,
        3020,
        3025,
        3030,
        3035,
        3040,
        3045,
        3050,
        3055,
        3060,
        3065,
        3070,
        3075,
        3080,
        3085,
        3090,
        3095,
        3100,
        3105,
        3110,
        3115,
        3120,
        3125,
        3130,
        3135,
        3140,
        3145,
        3150,
        3155,
        3160,
        3165,
        3170,
        3175,
        3180,
        3185,
        3190,
        3195,
        3200,
        3205,
        3210,
        3215,
        3220,
        3225,
        3230,
        3235,
        3240,
        3245,
        3250,
        3255,
        3260,
        3265,
        3270,
        3275,
        3280,
        3285,
        3290,
        3295,
        3300,
        3305,
        3310,
        3315,
        3320,
        3325,
        3330,
        3335,
        3340,
        3345,
        3350,
        3355,
        3360,
        3365,
        3370,
        3375,
        3380,
        3385,
        3390,
        3395,
        3400,
        3405,
        3410,
        3415,
        3420,
        3425,
        3430,
        3435,
        3440,
        3445,
        3450,
        3455,
        3460,
        3465,
        3470,
        3475,
        3480,
        3485,
        3490,
        3495,
        3500,
        3505,
        3510,
        3515,
        3520,
        3525,
        3530,
        3535,
        3540,
        3545,
        3550,
        3555,
        3560,
        3565,
        3570,
        3575,
        3580,
        3585,
        3590,
        3595,
        3600,
        3605,
        3610,
        3615,
        3620,
        3625,
        3630,
        3635,
        3640,
        3645,
        3650,
        3655,
        3660,
        3665,
        3670,
        3675,
        3680,
        3685,
        3690,
        3695,
        3700,
        3705,
        3710,
        3715,
        3720,
        3725,
        3730,
        3735,
        3740,
        3745,
        3750,
        3755,
        3760,
        3765,
        3770,
        3775,
        3780,
        3785,
        3790,
        3795,
        3800,
        3805,
        3810,
        3815,
        3820,
        3825,
        3830,
        3835,
        3840,
        3845,
        3850,
        3855,
        3860,
        3865,
        3870,
        3875,
        3880,
        3885,
        3890,
        3895,
        3900,
        3905,
        3910,
        3915,
        3920,
        3925,
        3930,
        3935,
        3940,
        3945,
        3950,
        3955,
        3960,
        3965,
        3970,
        3975,
        3980,
        3985,
        3990,
        3995,
        4000,
    ]
)

E_G173_global_tilt_W_per_m2_nm = numpy.array(
    [
        4.7309e-23,
        1.2307e-21,
        5.6895e-21,
        1.5662e-19,
        1.1946e-18,
        4.5436e-18,
        1.8452e-17,
        3.536e-17,
        7.267e-16,
        2.4856e-15,
        8.0142e-15,
        4.2613e-14,
        1.3684e-13,
        8.3823e-13,
        2.7367e-12,
        1.0903e-11,
        6.2337e-11,
        1.7162e-10,
        5.6265e-10,
        2.0749e-09,
        6.0168e-09,
        1.3783e-08,
        3.5052e-08,
        1.0913e-07,
        2.683e-07,
        4.2685e-07,
        8.6466e-07,
        2.2707e-06,
        4.1744e-06,
        6.5911e-06,
        1.229e-05,
        2.7826e-05,
        4.7904e-05,
        7.1345e-05,
        9.68e-05,
        0.00018608,
        0.00028988,
        0.00035789,
        0.00049211,
        0.00086068,
        0.0010205,
        0.001245,
        0.00193,
        0.0026914,
        0.0029209,
        0.004284,
        0.0070945,
        0.0089795,
        0.0094701,
        0.011953,
        0.016463,
        0.018719,
        0.018577,
        0.021108,
        0.027849,
        0.035635,
        0.037837,
        0.04143,
        0.040534,
        0.043306,
        0.050939,
        0.06554,
        0.082922,
        0.08408,
        0.093376,
        0.098984,
        0.10733,
        0.10757,
        0.11969,
        0.1306,
        0.13625,
        0.11838,
        0.12348,
        0.15036,
        0.17158,
        0.18245,
        0.17594,
        0.18591,
        0.2047,
        0.19589,
        0.20527,
        0.24525,
        0.25024,
        0.23843,
        0.22203,
        0.21709,
        0.21226,
        0.24861,
        0.27537,
        0.28321,
        0.27894,
        0.32436,
        0.3812,
        0.40722,
        0.39806,
        0.38465,
        0.35116,
        0.37164,
        0.42235,
        0.46878,
        0.47139,
        0.428,
        0.40262,
        0.41806,
        0.43623,
        0.43919,
        0.42944,
        0.40724,
        0.41497,
        0.44509,
        0.46388,
        0.45313,
        0.41519,
        0.38214,
        0.3738,
        0.40051,
        0.43411,
        0.45527,
        0.46355,
        0.47446,
        0.5018,
        0.50071,
        0.47139,
        0.46935,
        0.48934,
        0.50767,
        0.51489,
        0.48609,
        0.41843,
        0.40307,
        0.45898,
        0.48932,
        0.47778,
        0.48657,
        0.49404,
        0.47674,
        0.47511,
        0.48336,
        0.46564,
        0.47805,
        0.52798,
        0.56741,
        0.55172,
        0.53022,
        0.51791,
        0.48962,
        0.5204,
        0.57228,
        0.60498,
        0.61156,
        0.6114,
        0.59028,
        0.55387,
        0.51942,
        0.45673,
        0.46215,
        0.43006,
        0.39926,
        0.46953,
        0.56549,
        0.59817,
        0.56531,
        0.52024,
        0.50956,
        0.5342,
        0.5851,
        0.60191,
        0.58541,
        0.60628,
        0.60058,
        0.62359,
        0.68628,
        0.73532,
        0.73658,
        0.72285,
        0.70914,
        0.66759,
        0.6631,
        0.69315,
        0.74469,
        0.75507,
        0.68261,
        0.69338,
        0.72051,
        0.67444,
        0.64253,
        0.61886,
        0.55786,
        0.5564,
        0.55227,
        0.5893,
        0.65162,
        0.6748,
        0.6639,
        0.71225,
        0.79455,
        0.85595,
        0.83418,
        0.74389,
        0.66683,
        0.70077,
        0.75075,
        0.76383,
        0.68837,
        0.58678,
        0.50762,
        0.45499,
        0.44049,
        0.50968,
        0.61359,
        0.67355,
        0.64363,
        0.621,
        0.6457,
        0.65147,
        0.64204,
        0.63582,
        0.63136,
        0.68543,
        0.7597,
        0.79699,
        0.80371,
        0.85138,
        0.86344,
        0.79493,
        0.66257,
        0.47975,
        0.38152,
        0.49567,
        0.68385,
        0.80772,
        0.86038,
        0.75655,
        0.55017,
        0.42619,
        0.62945,
        0.85249,
        1.0069,
        1.0693,
        1.1021,
        1.1141,
        1.1603,
        1.2061,
        1.1613,
        1.1801,
        1.1511,
        1.1227,
        1.1026,
        1.1514,
        1.2299,
        1.0485,
        1.1738,
        1.2478,
        1.1971,
        1.1842,
        1.2258,
        1.2624,
        1.2312,
        1.1777,
        1.2258,
        1.1232,
        1.2757,
        1.2583,
        1.2184,
        1.2117,
        1.2488,
        1.2135,
        1.1724,
        1.1839,
        1.0963,
        0.87462,
        0.79394,
        1.3207,
        1.2288,
        1.1352,
        1.2452,
        1.3659,
        1.3943,
        1.2238,
        1.1775,
        1.3499,
        1.3313,
        1.425,
        1.4453,
        1.4084,
        1.4619,
        1.3108,
        1.4903,
        1.5081,
        1.5045,
        1.5595,
        1.6173,
        1.5482,
        1.4297,
        1.5335,
        1.5224,
        1.5724,
        1.5854,
        1.5514,
        1.5391,
        1.5291,
        1.5827,
        1.5975,
        1.6031,
        1.5544,
        1.535,
        1.5673,
        1.4973,
        1.5619,
        1.5682,
        1.5077,
        1.5331,
        1.6126,
        1.5499,
        1.5671,
        1.6185,
        1.5631,
        1.5724,
        1.623,
        1.5916,
        1.6181,
        1.6177,
        1.6236,
        1.6038,
        1.5734,
        1.5683,
        1.2716,
        1.4241,
        1.5413,
        1.4519,
        1.6224,
        1.5595,
        1.4869,
        1.5903,
        1.5525,
        1.6485,
        1.5676,
        1.5944,
        1.5509,
        1.5507,
        1.5451,
        1.4978,
        1.4966,
        1.5653,
        1.4587,
        1.5635,
        1.6264,
        1.556,
        1.5165,
        1.5893,
        1.5481,
        1.5769,
        1.6186,
        1.5206,
        1.4885,
        1.5314,
        1.5455,
        1.2594,
        1.4403,
        1.3957,
        1.5236,
        1.5346,
        1.569,
        1.4789,
        1.5905,
        1.5781,
        1.5341,
        1.3417,
        1.5357,
        1.6071,
        1.5446,
        1.6292,
        1.5998,
        1.4286,
        1.5302,
        1.5535,
        1.6199,
        1.4989,
        1.5738,
        1.5352,
        1.4825,
        1.4251,
        1.5511,
        1.5256,
        1.5792,
        1.5435,
        1.5291,
        1.549,
        1.5049,
        1.552,
        1.5399,
        1.5382,
        1.5697,
        1.525,
        1.5549,
        1.5634,
        1.5366,
        1.4988,
        1.531,
        1.4483,
        1.474,
        1.5595,
        1.4847,
        1.5408,
        1.5106,
        1.5201,
        1.4374,
        1.532,
        1.518,
        1.4807,
        1.4816,
        1.4331,
        1.5134,
        1.5198,
        1.5119,
        1.4777,
        1.4654,
        1.5023,
        1.456,
        1.477,
        1.502,
        1.5089,
        1.532,
        1.5479,
        1.5448,
        1.5324,
        1.4953,
        1.5281,
        1.4934,
        1.2894,
        1.3709,
        1.4662,
        1.4354,
        1.4561,
        1.4491,
        1.4308,
        1.4745,
        1.4788,
        1.4607,
        1.4606,
        1.4753,
        1.4579,
        1.436,
        1.4664,
        1.4921,
        1.4895,
        1.4822,
        1.4911,
        1.4862,
        1.4749,
        1.4686,
        1.4611,
        1.4831,
        1.4621,
        1.4176,
        1.4697,
        1.431,
        1.4128,
        1.4664,
        1.4733,
        1.4739,
        1.4802,
        1.4269,
        1.4165,
        1.4118,
        1.4026,
        1.4012,
        1.4417,
        1.3631,
        1.4114,
        1.3924,
        1.4161,
        1.3638,
        1.4508,
        1.4284,
        1.4458,
        1.4128,
        1.461,
        1.4707,
        1.4646,
        1.434,
        1.4348,
        1.4376,
        1.4525,
        1.4462,
        1.4567,
        1.415,
        1.4086,
        1.3952,
        1.3519,
        1.3594,
        1.4447,
        1.3871,
        1.4311,
        1.4153,
        1.3499,
        1.1851,
        1.2393,
        1.3855,
        1.3905,
        1.3992,
        1.3933,
        1.3819,
        1.3844,
        1.3967,
        1.4214,
        1.4203,
        1.4102,
        1.415,
        1.4394,
        1.4196,
        1.4169,
        1.3972,
        1.4094,
        1.4074,
        1.3958,
        1.412,
        1.3991,
        1.4066,
        1.3947,
        1.3969,
        1.3915,
        1.3981,
        1.383,
        1.3739,
        1.3748,
        1.3438,
        0.96824,
        1.1206,
        1.1278,
        1.1821,
        1.2333,
        1.2689,
        1.2609,
        1.2464,
        1.2714,
        1.2684,
        1.3403,
        1.3192,
        1.2918,
        1.2823,
        1.2659,
        1.2674,
        1.2747,
        1.3078,
        1.3214,
        1.3144,
        1.309,
        1.3048,
        1.3095,
        1.3175,
        1.3155,
        1.3071,
        1.2918,
        1.3029,
        1.2587,
        1.2716,
        1.1071,
        1.0296,
        0.92318,
        0.9855,
        1.0861,
        1.2407,
        1.1444,
        1.0555,
        1.038,
        1.0813,
        1.085,
        1.04,
        1.0466,
        1.1285,
        1.0703,
        1.1534,
        1.1962,
        1.2357,
        1.2178,
        1.2059,
        1.2039,
        1.2269,
        1.1905,
        1.2195,
        1.2148,
        1.2153,
        1.2405,
        1.2503,
        1.2497,
        1.247,
        1.2477,
        1.2401,
        1.2357,
        1.2341,
        1.2286,
        1.233,
        1.2266,
        1.242,
        1.2383,
        1.2232,
        1.2221,
        1.2295,
        1.1945,
        0.26604,
        0.15396,
        0.68766,
        0.37952,
        0.53878,
        0.68601,
        0.81461,
        0.97417,
        1.1138,
        1.1278,
        1.1608,
        1.1686,
        1.1778,
        1.1771,
        1.1771,
        1.1771,
        1.1798,
        1.1727,
        1.1713,
        1.1765,
        1.1636,
        1.1607,
        1.1662,
        1.1614,
        1.1536,
        1.1586,
        1.1592,
        1.145,
        1.1305,
        1.1257,
        1.091,
        1.1058,
        1.0953,
        1.0875,
        1.0972,
        1.0932,
        1.0742,
        1.0913,
        1.1121,
        1.0905,
        1.0725,
        1.0843,
        1.0856,
        1.0657,
        1.0782,
        1.0545,
        1.0974,
        1.0859,
        1.0821,
        1.0548,
        1.0559,
        1.0533,
        1.0268,
        1.0086,
        0.90356,
        0.89523,
        0.83216,
        0.85183,
        0.82259,
        0.90519,
        0.86188,
        0.99764,
        0.95157,
        0.67271,
        0.93506,
        0.96935,
        0.93381,
        0.98465,
        0.84979,
        0.9293,
        0.91601,
        0.92392,
        0.89426,
        0.9565,
        0.93412,
        1.0032,
        0.97234,
        1.0092,
        0.99901,
        1.0013,
        1.0157,
        1.0101,
        0.99703,
        1.0053,
        0.98631,
        1.0165,
        1.0187,
        0.9917,
        0.99217,
        0.98596,
        0.89372,
        0.97493,
        0.96927,
        0.96486,
        0.85112,
        0.913,
        0.97317,
        0.99166,
        0.99196,
        0.99171,
        0.98816,
        0.98679,
        0.99449,
        1.0005,
        0.97916,
        0.96324,
        0.849,
        0.91546,
        0.9592,
        0.94956,
        0.96755,
        0.95387,
        0.96686,
        0.95721,
        0.94042,
        0.92687,
        0.95277,
        0.95615,
        0.95237,
        0.93656,
        0.93957,
        0.90861,
        0.93245,
        0.92927,
        0.93305,
        0.94423,
        0.90752,
        0.91062,
        0.92228,
        0.93455,
        0.92393,
        0.92584,
        0.90881,
        0.87327,
        0.8513,
        0.81357,
        0.76253,
        0.66566,
        0.7178,
        0.54871,
        0.7426,
        0.59933,
        0.66791,
        0.68889,
        0.84457,
        0.81709,
        0.77558,
        0.63854,
        0.65217,
        0.70431,
        0.62467,
        0.66808,
        0.68893,
        0.62834,
        0.62649,
        0.67836,
        0.57646,
        0.73017,
        0.59271,
        0.73877,
        0.74414,
        0.78049,
        0.70026,
        0.74504,
        0.7215,
        0.7111,
        0.70331,
        0.78742,
        0.58968,
        0.55127,
        0.4321,
        0.40921,
        0.30086,
        0.24841,
        0.1438,
        0.25084,
        0.16142,
        0.16338,
        0.20058,
        0.39887,
        0.47181,
        0.37195,
        0.40532,
        0.27834,
        0.28579,
        0.36821,
        0.19461,
        0.37112,
        0.27423,
        0.49396,
        0.14726,
        0.48378,
        0.26891,
        0.34362,
        0.42411,
        0.34117,
        0.32821,
        0.27067,
        0.46101,
        0.37385,
        0.42066,
        0.4612,
        0.44174,
        0.50503,
        0.4586,
        0.50374,
        0.50275,
        0.5024,
        0.6521,
        0.68622,
        0.63461,
        0.71397,
        0.68765,
        0.60648,
        0.57529,
        0.58987,
        0.57191,
        0.63864,
        0.61509,
        0.63815,
        0.60468,
        0.71338,
        0.69218,
        0.66865,
        0.73732,
        0.68817,
        0.75083,
        0.73928,
        0.73462,
        0.74906,
        0.73227,
        0.75358,
        0.75102,
        0.73728,
        0.7541,
        0.75176,
        0.74884,
        0.73971,
        0.73887,
        0.73857,
        0.73532,
        0.74442,
        0.72805,
        0.73442,
        0.72336,
        0.68174,
        0.71252,
        0.72753,
        0.72685,
        0.71972,
        0.71914,
        0.72278,
        0.71877,
        0.71761,
        0.72068,
        0.70817,
        0.71129,
        0.70337,
        0.71422,
        0.68878,
        0.69896,
        0.70175,
        0.6897,
        0.69508,
        0.69058,
        0.69753,
        0.69636,
        0.69305,
        0.69385,
        0.68628,
        0.69055,
        0.68736,
        0.68787,
        0.67613,
        0.68015,
        0.68234,
        0.68202,
        0.67497,
        0.67172,
        0.67636,
        0.6717,
        0.67176,
        0.672,
        0.66525,
        0.66833,
        0.66452,
        0.64714,
        0.65694,
        0.66274,
        0.65896,
        0.65463,
        0.65521,
        0.65118,
        0.64919,
        0.64646,
        0.64847,
        0.64641,
        0.64482,
        0.63818,
        0.61875,
        0.63585,
        0.62121,
        0.63266,
        0.62239,
        0.63196,
        0.62913,
        0.61713,
        0.62032,
        0.61944,
        0.58626,
        0.60469,
        0.61661,
        0.61536,
        0.60363,
        0.62158,
        0.59252,
        0.61471,
        0.60434,
        0.60321,
        0.60474,
        0.59722,
        0.58083,
        0.5894,
        0.59814,
        0.57852,
        0.5933,
        0.5541,
        0.56697,
        0.59317,
        0.57919,
        0.55573,
        0.58835,
        0.58124,
        0.51058,
        0.53965,
        0.52067,
        0.50323,
        0.57852,
        0.50291,
        0.50772,
        0.48577,
        0.49696,
        0.46883,
        0.46637,
        0.46765,
        0.50644,
        0.39792,
        0.48304,
        0.41565,
        0.41278,
        0.47899,
        0.33154,
        0.41357,
        0.2685,
        0.29985,
        0.24987,
        0.20136,
        0.079618,
        0.21753,
        0.11317,
        0.14189,
        0.18586,
        0.081686,
        0.12817,
        0.1087,
        0.14428,
        0.051589,
        0.15725,
        0.099224,
        0.10591,
        0.070574,
        0.2956,
        0.23411,
        0.15331,
        0.04174,
        0.015462,
        0.12876,
        0.28785,
        0.20329,
        0.2985,
        0.25599,
        0.19337,
        0.22479,
        0.31183,
        0.11326,
        0.14604,
        0.15764,
        0.059176,
        0.27113,
        0.21854,
        0.12164,
        0.2034,
        0.24762,
        0.23812,
        0.14248,
        0.31316,
        0.2809,
        0.31458,
        0.31171,
        0.33693,
        0.28648,
        0.34753,
        0.35002,
        0.46857,
        0.40188,
        0.3886,
        0.37494,
        0.40996,
        0.41954,
        0.4231,
        0.45873,
        0.44831,
        0.45483,
        0.45642,
        0.33692,
        0.4524,
        0.47679,
        0.47235,
        0.36,
        0.48371,
        0.44069,
        0.45514,
        0.32318,
        0.4387,
        0.41985,
        0.40741,
        0.47715,
        0.45575,
        0.33504,
        0.41569,
        0.46239,
        0.4466,
        0.47336,
        0.45434,
        0.4689,
        0.44696,
        0.43131,
        0.47715,
        0.43392,
        0.36489,
        0.44825,
        0.43708,
        0.43717,
        0.43409,
        0.36247,
        0.43692,
        0.48086,
        0.42986,
        0.43346,
        0.41428,
        0.45336,
        0.42232,
        0.42489,
        0.46956,
        0.43407,
        0.4278,
        0.4664,
        0.45528,
        0.45934,
        0.44663,
        0.45805,
        0.46531,
        0.45139,
        0.44406,
        0.44808,
        0.46236,
        0.46819,
        0.43304,
        0.46658,
        0.46721,
        0.46003,
        0.47203,
        0.46633,
        0.45397,
        0.47016,
        0.46504,
        0.46908,
        0.46339,
        0.46797,
        0.46272,
        0.46077,
        0.46197,
        0.46247,
        0.45754,
        0.45528,
        0.45655,
        0.45945,
        0.45746,
        0.4586,
        0.45966,
        0.45705,
        0.45258,
        0.45097,
        0.44773,
        0.44363,
        0.4507,
        0.44023,
        0.43532,
        0.44496,
        0.42725,
        0.4311,
        0.41146,
        0.39567,
        0.40019,
        0.37148,
        0.3957,
        0.38527,
        0.38822,
        0.37051,
        0.24652,
        0.38744,
        0.40825,
        0.40879,
        0.40625,
        0.40614,
        0.41233,
        0.41693,
        0.42001,
        0.42763,
        0.42456,
        0.42204,
        0.41335,
        0.37305,
        0.40733,
        0.42078,
        0.42399,
        0.42714,
        0.42213,
        0.41989,
        0.40936,
        0.41285,
        0.41786,
        0.39618,
        0.41257,
        0.40421,
        0.40514,
        0.38957,
        0.3713,
        0.39183,
        0.40852,
        0.35312,
        0.36228,
        0.39181,
        0.34621,
        0.30062,
        0.38382,
        0.38453,
        0.30594,
        0.34696,
        0.38413,
        0.30114,
        0.33366,
        0.33337,
        0.31352,
        0.28833,
        0.28581,
        0.32419,
        0.31217,
        0.33328,
        0.26855,
        0.25872,
        0.29866,
        0.30217,
        0.23279,
        0.26249,
        0.32224,
        0.28051,
        0.26625,
        0.2345,
        0.17759,
        0.22923,
        0.1448,
        0.14579,
        0.20304,
        0.16925,
        0.23117,
        0.18348,
        0.16454,
        0.17804,
        0.17681,
        0.16831,
        0.17039,
        0.17798,
        0.12711,
        0.075645,
        0.10904,
        0.058186,
        0.060119,
        0.0047451,
        0.016159,
        0.016025,
        0.0046298,
        0.0015164,
        9.6096e-05,
        0.00029009,
        3.6034e-06,
        4.807e-05,
        7.1786e-05,
        4.1948e-06,
        7.3439e-07,
        2.1404e-06,
        4.8133e-09,
        1.8076e-11,
        3.1563e-06,
        1.3589e-06,
        9.0764e-12,
        1.2791e-05,
        4.9764e-06,
        1.481e-13,
        5.1667e-07,
        2.92e-07,
        1.9731e-08,
        2.7498e-06,
        4.4401e-05,
        0.00017917,
        0.00032332,
        0.00025748,
        0.0001227,
        0.0011089,
        5.2164e-05,
        8.1587e-05,
        2.3716e-06,
        2.5672e-06,
        4.4017e-08,
        6.1689e-07,
        2.0899e-06,
        2.5215e-06,
        0.00019896,
        4.0262e-06,
        0.00058098,
        0.00049328,
        0.00034384,
        2.3782e-05,
        0.00011586,
        7.5526e-05,
        6.7136e-07,
        6.3215e-09,
        4.9057e-05,
        0.0012704,
        0.00081226,
        3.2466e-09,
        1.0528e-08,
        0.0018353,
        0.00238,
        0.00073892,
        3.6444e-07,
        0.0020448,
        0.00017457,
        0.0016493,
        0.00061919,
        0.00046653,
        0.0021142,
        0.0026396,
        0.023353,
        0.00036378,
        0.00018366,
        0.035565,
        0.011759,
        0.013559,
        0.0021442,
        0.0082718,
        0.0091637,
        0.046314,
        0.0092198,
        0.016975,
        0.02585,
        0.027792,
        0.049546,
        0.0045588,
        0.03802,
        0.061601,
        0.050156,
        0.0025194,
        0.035834,
        0.020962,
        0.021416,
        0.038351,
        0.02988,
        0.013263,
        0.051039,
        0.039601,
        0.0318,
        0.036317,
        0.045063,
        0.061791,
        0.049751,
        0.023095,
        0.036215,
        0.11569,
        0.10213,
        0.027412,
        0.011271,
        0.062361,
        0.081978,
        0.13759,
        0.06615,
        0.088509,
        0.117,
        0.13643,
        0.16307,
        0.085421,
        0.090276,
        0.1306,
        0.043225,
        0.15184,
        0.093383,
        0.065197,
        0.036054,
        0.076942,
        0.094845,
        0.049678,
        0.017848,
        0.046771,
        0.070198,
        0.097339,
        0.18463,
        0.068778,
        0.069736,
        0.06348,
        0.12001,
        0.060637,
        0.11529,
        0.05849,
        0.14859,
        0.13747,
        0.12503,
        0.1234,
        0.060629,
        0.09418,
        0.18973,
        0.17478,
        0.19778,
        0.16441,
        0.18157,
        0.20367,
        0.18253,
        0.16852,
        0.2285,
        0.18968,
        0.21759,
        0.25061,
        0.26552,
        0.23356,
        0.18493,
        0.16029,
        0.18402,
        0.25773,
        0.25514,
        0.24302,
        0.1869,
        0.27052,
        0.26474,
        0.26068,
        0.24239,
        0.22571,
        0.26573,
        0.25683,
        0.24929,
        0.25211,
        0.24437,
        0.2645,
        0.27505,
        0.26378,
        0.28004,
        0.27539,
        0.25884,
        0.26745,
        0.2622,
        0.27928,
        0.27244,
        0.25522,
        0.26973,
        0.27839,
        0.27714,
        0.26892,
        0.26686,
        0.27464,
        0.27336,
        0.27202,
        0.27295,
        0.26491,
        0.26904,
        0.26927,
        0.27208,
        0.2721,
        0.27705,
        0.27481,
        0.27309,
        0.26675,
        0.27342,
        0.2699,
        0.27058,
        0.27182,
        0.27132,
        0.26474,
        0.26759,
        0.2631,
        0.27062,
        0.26848,
        0.26808,
        0.26568,
        0.27002,
        0.26756,
        0.26667,
        0.26264,
        0.26728,
        0.26245,
        0.26308,
        0.25722,
        0.25452,
        0.24175,
        0.23507,
        0.23775,
        0.23407,
        0.24145,
        0.23974,
        0.24678,
        0.21602,
        0.23516,
        0.23672,
        0.24464,
        0.2487,
        0.24195,
        0.24755,
        0.24904,
        0.25874,
        0.25569,
        0.25303,
        0.25107,
        0.23233,
        0.24179,
        0.24197,
        0.25225,
        0.25833,
        0.25624,
        0.25823,
        0.24452,
        0.24692,
        0.25421,
        0.24202,
        0.2381,
        0.22323,
        0.22413,
        0.22397,
        0.22842,
        0.23683,
        0.2414,
        0.23296,
        0.2299,
        0.22727,
        0.2176,
        0.2268,
        0.23076,
        0.23719,
        0.23838,
        0.24104,
        0.2305,
        0.23465,
        0.24352,
        0.241,
        0.23449,
        0.2343,
        0.23754,
        0.24246,
        0.24269,
        0.23782,
        0.23971,
        0.24078,
        0.24126,
        0.24137,
        0.23651,
        0.23806,
        0.23821,
        0.23267,
        0.23282,
        0.23367,
        0.23539,
        0.227,
        0.22007,
        0.22026,
        0.21511,
        0.2196,
        0.22082,
        0.21535,
        0.22355,
        0.21822,
        0.21749,
        0.22768,
        0.21655,
        0.21867,
        0.22526,
        0.20855,
        0.22373,
        0.22277,
        0.21583,
        0.22231,
        0.22101,
        0.22223,
        0.22487,
        0.2212,
        0.22332,
        0.22384,
        0.21908,
        0.22235,
        0.22098,
        0.21178,
        0.17884,
        0.21068,
        0.21459,
        0.21516,
        0.22168,
        0.21879,
        0.21147,
        0.21629,
        0.21575,
        0.2136,
        0.21145,
        0.21229,
        0.20915,
        0.21303,
        0.20558,
        0.19447,
        0.20366,
        0.20906,
        0.19797,
        0.21321,
        0.21026,
        0.20484,
        0.21013,
        0.20718,
        0.20523,
        0.19303,
        0.20708,
        0.21134,
        0.20477,
        0.20968,
        0.20922,
        0.18107,
        0.20739,
        0.20551,
        0.19975,
        0.20396,
        0.19778,
        0.1879,
        0.18965,
        0.18698,
        0.17808,
        0.17407,
        0.16154,
        0.16818,
        0.15481,
        0.16566,
        0.15301,
        0.15998,
        0.13284,
        0.14172,
        0.11484,
        0.1005,
        0.076981,
        0.088904,
        0.046931,
        0.031828,
        0.014815,
        0.0096911,
        0.0032816,
        0.00098755,
        0.0012744,
        5.2041e-06,
        6.419e-06,
        6.2703e-08,
        6.2658e-06,
        2.9993e-06,
        2.8396e-07,
        1.1151e-05,
        1.6982e-05,
        2.6662e-10,
        4.513e-10,
        7.7505e-05,
        4.389e-05,
        0.00022333,
        0.00012947,
        8.6221e-07,
        5.6667e-07,
        2.3045e-05,
        1.9947e-05,
        0.00045069,
        0.00093615,
        0.00055242,
        0.0035935,
        0.0032821,
        0.010863,
        0.016727,
        0.010036,
        0.021906,
        0.028563,
        0.048847,
        0.067857,
        0.075512,
        0.083063,
        0.085613,
        0.08119,
        0.038156,
        0.015001,
        0.039748,
        0.026648,
        0.044981,
        0.07401,
        0.084856,
        0.096386,
        0.089781,
        0.091074,
        0.067927,
        0.054906,
        0.069193,
        0.061875,
        0.065676,
        0.077443,
        0.086812,
        0.085102,
        0.0891,
        0.089747,
        0.086133,
        0.093153,
        0.089654,
        0.091673,
        0.087588,
        0.088632,
        0.089774,
        0.090044,
        0.090767,
        0.089486,
        0.084639,
        0.08484,
        0.08417,
        0.07631,
        0.081996,
        0.080448,
        0.081808,
        0.07455,
        0.079068,
        0.078992,
        0.071202,
        0.07401,
        0.079315,
        0.076273,
        0.07773,
        0.075453,
        0.075773,
        0.074299,
        0.073118,
        0.070838,
        0.071937,
        0.06769,
        0.066929,
        0.068137,
        0.064867,
        0.064021,
        0.066288,
        0.06308,
        0.06322,
        0.061265,
        0.058824,
        0.059171,
        0.06387,
        0.058141,
        0.052031,
        0.056215,
        0.056824,
        0.057967,
        0.045836,
        0.0514,
        0.041536,
        0.047473,
        0.050237,
        0.049409,
        0.030817,
        0.044147,
        0.042552,
        0.030826,
        0.037109,
        0.040594,
        0.04415,
        0.033599,
        0.033813,
        0.0273,
        0.02659,
        0.033078,
        0.045099,
        0.014878,
        0.043249,
        0.020798,
        0.013611,
        0.024853,
        0.033363,
        0.024148,
        0.016727,
        0.016455,
        0.0080395,
        0.0056102,
        0.0035113,
        0.0028772,
        0.0070642,
        0.0015191,
        0.0022163,
        0.0005188,
        0.00037054,
        4.1393e-05,
        6.3593e-07,
        1.7502e-07,
        3.7716e-07,
        5.3758e-11,
        2.8222e-13,
        1.0435e-09,
        3.102e-11,
        1.5955e-14,
        1.5258e-18,
        1.0786e-27,
        3.8214e-22,
        1.7194e-34,
        5.4793e-31,
        2.2838e-33,
        4.4912e-28,
        5.8053e-35,
        5.9447e-34,
        1.1196e-37,
        5.6505e-29,
        3.8687e-28,
        2.8026e-45,
        3.9027e-16,
        1.175e-16,
        8.9988e-19,
        1.4295e-19,
        1.3133e-27,
        2.6068e-25,
        1.1123e-37,
        0,
        0,
        0,
        0,
        1.0226e-29,
        7.1284e-33,
        0,
        2.9315e-42,
        1.125e-35,
        3.8557e-26,
        5.6052e-45,
        7.2935e-22,
        6.0734e-19,
        5.4888e-21,
        2.3314e-27,
        1.3146e-23,
        1.6648e-28,
        6.7262e-44,
        0,
        2.6777e-27,
        8.3791e-24,
        3.999e-38,
        4.8067e-34,
        3.8866e-27,
        1.217e-16,
        3.6205e-16,
        1.6484e-12,
        6.7478e-14,
        4.0233e-10,
        2.8685e-10,
        2.0548e-11,
        1.7605e-07,
        3.9008e-06,
        2.1276e-10,
        1.9609e-07,
        4.0575e-05,
        1.1566e-06,
        4.4867e-07,
        2.5356e-05,
        0.00016763,
        6.3129e-06,
        0.0003917,
        0.00024724,
        0.00045332,
        0.00018623,
        0.0026643,
        0.00081152,
        0.00011096,
        0.002722,
        0.0012581,
        0.0028948,
        0.0010835,
        0.0058858,
        0.0064903,
        0.0016273,
        0.0014489,
        0.0052276,
        0.0023361,
        0.0045971,
        0.0074379,
        0.00035233,
        0.00085429,
        0.0013381,
        0.0069628,
        0.01028,
        0.0042755,
        0.0078472,
        0.0028906,
        0.0068479,
        0.0055551,
        0.00063369,
        0.0075031,
        0.0060753,
        0.0024986,
        0.0020242,
        0.004209,
        0.0010321,
        0.00028947,
        0.0063012,
        0.0029113,
        0.0017492,
        0.0060221,
        0.0036224,
        0.0017671,
        0.0023805,
        0.0006551,
        0.004401,
        0.00092155,
        0.00084569,
        0.0022677,
        0.0098197,
        0.0030289,
        0.0057614,
        0.011446,
        0.0033241,
        0.0032517,
        0.0066744,
        0.0056366,
        0.009232,
        0.014017,
        0.012516,
        0.0092302,
        0.010621,
        0.0080823,
        0.0042388,
        0.0026927,
        0.00043843,
        0.00030973,
        0.00013634,
        0.00049752,
        0.0016089,
        0.00019875,
        0.0003408,
        0.007294,
        0.0037464,
        0.00073409,
        0.0026067,
        0.0099378,
        0.0012248,
        0.0024465,
        0.0012186,
        0.0059265,
        0.0028644,
        0.011128,
        0.0087571,
        0.0012234,
        0.0017794,
        0.0039416,
        0.0039235,
        1.6133e-05,
        5.9987e-05,
        0.0035187,
        0.0046616,
        0.0090694,
        0.0034602,
        0.0035408,
        0.0080277,
        0.0036308,
        0.0052402,
        0.0071907,
        0.0039389,
        0.008456,
        0.0051115,
        0.0074896,
        0.0098552,
        0.0095465,
        0.012509,
        0.0044594,
        0.0070802,
        0.0072774,
        0.013165,
        0.010006,
        0.0086892,
        0.011553,
        0.0080348,
        0.011318,
        0.011153,
        0.0083089,
        0.01253,
        0.0098179,
        0.012264,
        0.010943,
        0.011224,
        0.012094,
        0.010419,
        0.012265,
        0.011917,
        0.011809,
        0.011963,
        0.011494,
        0.012122,
        0.011428,
        0.011127,
        0.0094556,
        0.009031,
        0.0095432,
        0.010538,
        0.0090581,
        0.010795,
        0.010851,
        0.0083376,
        0.0086444,
        0.010187,
        0.0091671,
        0.0094523,
        0.00967,
        0.010262,
        0.010359,
        0.0094787,
        0.0094726,
        0.011614,
        0.010239,
        0.009955,
        0.010299,
        0.01148,
        0.010599,
        0.010123,
        0.010978,
        0.010914,
        0.010253,
        0.0079003,
        0.0048286,
        0.0083312,
        0.009438,
        0.0096922,
        0.010132,
        0.010878,
        0.01077,
        0.009364,
        0.0092254,
        0.010376,
        0.010698,
        0.0092707,
        0.0085837,
        0.0088494,
        0.010331,
        0.0092903,
        0.0089918,
        0.0088633,
        0.0085502,
        0.0091243,
        0.0090521,
        0.0095746,
        0.0088123,
        0.0077564,
        0.0088692,
        0.0098592,
        0.0093049,
        0.0082451,
        0.0077569,
        0.009655,
        0.0095056,
        0.0095925,
        0.0076916,
        0.0089756,
        0.0087801,
        0.0088274,
        0.0085085,
        0.007994,
        0.0080989,
        0.0073604,
        0.006762,
        0.006534,
        0.0067717,
        0.0068818,
        0.007476,
        0.0079254,
        0.0079269,
        0.0071353,
        0.0069868,
        0.0069466,
        0.006852,
        0.0070502,
        0.0073541,
        0.0074027,
        0.0075412,
        0.0076277,
        0.0077199,
        0.0077482,
        0.0078057,
        0.0076806,
        0.0075097,
        0.0073872,
        0.0074327,
        0.0073723,
        0.00721,
        0.0071043,
    ]
)
E_G173_global_tilt = computation.SpectralIrradiance(
    lambda_nm=lambda_G173_global_tilt_nm, E_W_per_m2_nm=E_G173_global_tilt_W_per_m2_nm
)

# Sample data at Standard Test Condition (STC).
# Special thanks to Behrang Hamadani from NIST for providing, https://www.nist.gov/people/behrang-hamadani.
# See https://onlinelibrary.wiley.com/doi/full/10.1002/ese3.190
lambda_nm_RD_NIST = numpy.array(
    [
        279.968,
        300.004,
        320.028,
        339.965,
        359.964,
        380.025,
        399.996,
        420.027,
        439.967,
        459.966,
        480.021,
        499.984,
        520.002,
        539.999,
        559.976,
        580.007,
        600.014,
        619.999,
        640.033,
        659.968,
        680.026,
        699.983,
        719.983,
        739.964,
        759.989,
        779.985,
        800.023,
        820.029,
        840.002,
        860.015,
        879.993,
        900.008,
        919.987,
        940.001,
        959.977,
        979.986,
        1000.027,
        1020.025,
        1039.982,
        1059.968,
        1079.98,
        1100.018,
        1120.01,
        1140.026,
        1159.993,
        1179.98,
        1199.989,
    ]
)

S_A_per_W_RD_NIST = numpy.array(
    [
        0.055997362,
        0.078006294,
        0.096250573,
        0.108405081,
        0.119247612,
        0.142906682,
        0.187211301,
        0.226795172,
        0.260776918,
        0.290206768,
        0.315160585,
        0.337707572,
        0.357824193,
        0.376719258,
        0.39688994,
        0.41274885,
        0.430532834,
        0.444902624,
        0.460541946,
        0.474604358,
        0.489572868,
        0.503263653,
        0.515626979,
        0.52911119,
        0.540838845,
        0.552316859,
        0.561862951,
        0.57300856,
        0.580587879,
        0.586679188,
        0.590638082,
        0.591127106,
        0.588134923,
        0.578593131,
        0.561390745,
        0.534154456,
        0.500171343,
        0.455022862,
        0.393347115,
        0.307878406,
        0.233917304,
        0.167444255,
        0.114536749,
        0.064545571,
        0.026877939,
        0.004238535,
        0.001337886,
    ]
)

S_RD_NIST = computation.SpectralResponsivity(
    lambda_nm=lambda_nm_RD_NIST, S_A_per_W=S_A_per_W_RD_NIST
)

lambda_nm_TD_NIST = numpy.array(
    [
        279.968,
        300.004,
        320.028,
        339.965,
        359.964,
        380.025,
        399.996,
        420.027,
        439.967,
        459.966,
        480.021,
        499.984,
        520.002,
        539.999,
        559.976,
        580.007,
        600.014,
        619.999,
        640.033,
        659.968,
        680.026,
        699.983,
        719.983,
        739.964,
        759.989,
        779.985,
        800.023,
        820.029,
        840.002,
        860.015,
        879.993,
        900.008,
        919.987,
        940.001,
        959.977,
        979.986,
        1000.027,
        1020.025,
        1039.982,
        1059.968,
        1079.98,
        1100.018,
        1120.01,
        1140.026,
        1159.993,
        1179.98,
        1199.989,
    ]
)

S_A_per_W_TD_NIST = numpy.array(
    [
        0.070491367,
        0.08445833,
        0.098896938,
        0.109646364,
        0.117210319,
        0.13721041,
        0.177473625,
        0.211657742,
        0.238819545,
        0.262902566,
        0.284013123,
        0.303580768,
        0.321789112,
        0.33900817,
        0.357345163,
        0.372261141,
        0.388375772,
        0.40262061,
        0.417121636,
        0.430978707,
        0.44477097,
        0.458944826,
        0.470249004,
        0.483779405,
        0.495353541,
        0.506793583,
        0.516349958,
        0.526672699,
        0.533033506,
        0.537712719,
        0.540188259,
        0.538128748,
        0.531225809,
        0.5156666,
        0.490020945,
        0.449281729,
        0.396764142,
        0.338965677,
        0.288003925,
        0.244359549,
        0.209356296,
        0.171166667,
        0.133647127,
        0.085673381,
        0.039595664,
        0.006489507,
        0.002040056,
    ]
)

S_TD_NIST = computation.SpectralResponsivity(
    lambda_nm=lambda_nm_TD_NIST, S_A_per_W=S_A_per_W_TD_NIST
)

lambda_nm_sim_NIST = numpy.array(
    [
        250.0835,
        250.9111,
        251.7389,
        252.5667,
        253.3945,
        254.2225,
        255.0504,
        255.8784,
        256.7065,
        257.5346,
        258.3628,
        259.191,
        260.0193,
        260.8476,
        261.676,
        262.5045,
        263.333,
        264.1615,
        264.9901,
        265.8187,
        266.6474,
        267.4761,
        268.3049,
        269.1338,
        269.9626,
        270.7916,
        271.6205,
        272.4496,
        273.2786,
        274.1077,
        274.9369,
        275.7661,
        276.5953,
        277.4246,
        278.254,
        279.0833,
        279.9128,
        280.7422,
        281.5717,
        282.4013,
        283.2309,
        284.0605,
        284.8902,
        285.7199,
        286.5496,
        287.3794,
        288.2093,
        289.0391,
        289.869,
        290.699,
        291.529,
        292.359,
        293.189,
        294.0191,
        294.8493,
        295.6794,
        296.5096,
        297.3399,
        298.1701,
        299.0005,
        299.8308,
        300.6612,
        301.4916,
        302.322,
        303.1525,
        303.983,
        304.8135,
        305.6441,
        306.4747,
        307.3053,
        308.136,
        308.9667,
        309.7974,
        310.6281,
        311.4589,
        312.2897,
        313.1205,
        313.9514,
        314.7823,
        315.6132,
        316.4441,
        317.2751,
        318.1061,
        318.9371,
        319.7682,
        320.5992,
        321.4303,
        322.2615,
        323.0926,
        323.9238,
        324.755,
        325.5862,
        326.4174,
        327.2487,
        328.0799,
        328.9112,
        329.7426,
        330.5739,
        331.4053,
        332.2367,
        333.0681,
        333.8995,
        334.7309,
        335.5624,
        336.3939,
        337.2254,
        338.0569,
        338.8884,
        339.72,
        340.5515,
        341.3831,
        342.2147,
        343.0463,
        343.878,
        344.7096,
        345.5413,
        346.373,
        347.2046,
        348.0364,
        348.8681,
        349.6998,
        350.5315,
        351.3633,
        352.195,
        353.0268,
        353.8586,
        354.6904,
        355.5222,
        356.3541,
        357.1859,
        358.0177,
        358.8496,
        359.6814,
        360.5133,
        361.3452,
        362.1771,
        363.009,
        363.8409,
        364.6728,
        365.5047,
        366.3366,
        367.1686,
        368.0005,
        368.8324,
        369.6644,
        370.4963,
        371.3283,
        372.1603,
        372.9922,
        373.8242,
        374.6562,
        375.4881,
        376.3201,
        377.1521,
        377.9841,
        378.8161,
        379.6481,
        380.48,
        381.312,
        382.144,
        382.976,
        383.808,
        384.64,
        385.472,
        386.304,
        387.136,
        387.9679,
        388.7999,
        389.6319,
        390.4639,
        391.2959,
        392.1279,
        392.9598,
        393.7918,
        394.6238,
        395.4557,
        396.2877,
        397.1196,
        397.9516,
        398.7835,
        399.6155,
        400.4474,
        401.2793,
        402.1112,
        402.9432,
        403.7751,
        404.607,
        405.4389,
        406.2708,
        407.1026,
        407.9345,
        408.7664,
        409.5982,
        410.43,
        411.2619,
        412.0937,
        412.9255,
        413.7573,
        414.5891,
        415.4209,
        416.2527,
        417.0844,
        417.9162,
        418.7479,
        419.5796,
        420.4113,
        421.243,
        422.0747,
        422.9064,
        423.738,
        424.5697,
        425.4013,
        426.2329,
        427.0645,
        427.8961,
        428.7277,
        429.5593,
        430.3908,
        431.2223,
        432.0538,
        432.8853,
        433.7168,
        434.5482,
        435.3797,
        436.2111,
        437.0425,
        437.8739,
        438.7053,
        439.5366,
        440.368,
        441.1993,
        442.0306,
        442.8618,
        443.6931,
        444.5243,
        445.3555,
        446.1867,
        447.0179,
        447.849,
        448.6802,
        449.5113,
        450.3424,
        451.1734,
        452.0045,
        452.8355,
        453.6665,
        454.4975,
        455.3284,
        456.1593,
        456.9902,
        457.8211,
        458.652,
        459.4828,
        460.3136,
        461.1444,
        461.9751,
        462.8059,
        463.6366,
        464.4672,
        465.2979,
        466.1285,
        466.9591,
        467.7897,
        468.6202,
        469.4507,
        470.2812,
        471.1117,
        471.9421,
        472.7725,
        473.6029,
        474.4332,
        475.2636,
        476.0938,
        476.9241,
        477.7543,
        478.5845,
        479.4147,
        480.2448,
        481.0749,
        481.905,
        482.7351,
        483.5651,
        484.3951,
        485.225,
        486.0549,
        486.8848,
        487.7147,
        488.5445,
        489.3743,
        490.204,
        491.0338,
        491.8635,
        492.6931,
        493.5227,
        494.3523,
        495.1819,
        496.0114,
        496.8409,
        497.6703,
        498.4997,
        499.3291,
        500.1584,
        500.9878,
        501.817,
        502.6463,
        503.4755,
        504.3046,
        505.1337,
        505.9628,
        506.7919,
        507.6209,
        508.4499,
        509.2788,
        510.1077,
        510.9366,
        511.7654,
        512.5942,
        513.4229,
        514.2516,
        515.0803,
        515.9089,
        516.7375,
        517.566,
        518.3945,
        519.223,
        520.0514,
        520.8798,
        521.7081,
        522.5364,
        523.3647,
        524.1929,
        525.0211,
        525.8492,
        526.6773,
        527.5054,
        528.3334,
        529.1614,
        529.9893,
        530.8172,
        531.645,
        532.4728,
        533.3005,
        534.1282,
        534.9559,
        535.7835,
        536.6111,
        537.4386,
        538.2661,
        539.0936,
        539.921,
        540.7483,
        541.5756,
        542.4029,
        543.2301,
        544.0572,
        544.8844,
        545.7115,
        546.5385,
        547.3655,
        548.1924,
        549.0193,
        549.8461,
        550.6729,
        551.4997,
        552.3264,
        553.153,
        553.9796,
        554.8062,
        555.6327,
        556.4592,
        557.2856,
        558.1119,
        558.9382,
        559.7645,
        560.5907,
        561.4169,
        562.243,
        563.0691,
        563.8951,
        564.721,
        565.547,
        566.3728,
        567.1986,
        568.0244,
        568.8501,
        569.6758,
        570.5014,
        571.3269,
        572.1525,
        572.9779,
        573.8033,
        574.6287,
        575.454,
        576.2792,
        577.1044,
        577.9295,
        578.7546,
        579.5797,
        580.4047,
        581.2296,
        582.0545,
        582.8793,
        583.7041,
        584.5288,
        585.3534,
        586.1781,
        587.0026,
        587.8271,
        588.6516,
        589.476,
        590.3003,
        591.1246,
        591.9488,
        592.773,
        593.5971,
        594.4212,
        595.2452,
        596.0691,
        596.893,
        597.7169,
        598.5406,
        599.3644,
        600.188,
        601.0117,
        601.8352,
        602.6587,
        603.4822,
        604.3055,
        605.1289,
        605.9521,
        606.7754,
        607.5985,
        608.4216,
        609.2447,
        610.0676,
        610.8906,
        611.7134,
        612.5362,
        613.359,
        614.1817,
        615.0043,
        615.8269,
        616.6494,
        617.4719,
        618.2943,
        619.1166,
        619.9389,
        620.7611,
        621.5833,
        622.4054,
        623.2274,
        624.0494,
        624.8713,
        625.6932,
        626.515,
        627.3368,
        628.1584,
        628.9801,
        629.8016,
        630.6231,
        631.4446,
        632.2659,
        633.0873,
        633.9085,
        634.7297,
        635.5508,
        636.3719,
        637.1929,
        638.0139,
        638.8347,
        639.6556,
        640.4763,
        641.297,
        642.1177,
        642.9383,
        643.7588,
        644.5792,
        645.3996,
        646.2199,
        647.0402,
        647.8604,
        648.6805,
        649.5006,
        650.3206,
        651.1406,
        651.9605,
        652.7803,
        653.6,
        654.4197,
        655.2394,
        656.0589,
        656.8784,
        657.6979,
        658.5172,
        659.3366,
        660.1558,
        660.975,
        661.7941,
        662.6132,
        663.4321,
        664.2511,
        665.0699,
        665.8887,
        666.7075,
        667.5261,
        668.3447,
        669.1633,
        669.9817,
        670.8001,
        671.6185,
        672.4368,
        673.255,
        674.0731,
        674.8912,
        675.7092,
        676.5272,
        677.345,
        678.1629,
        678.9806,
        679.7983,
        680.6159,
        681.4334,
        682.2509,
        683.0684,
        683.8857,
        684.703,
        685.5202,
        686.3374,
        687.1544,
        687.9715,
        688.7884,
        689.6053,
        690.4221,
        691.2389,
        692.0556,
        692.8722,
        693.6887,
        694.5052,
        695.3216,
        696.138,
        696.9543,
        697.7705,
        698.5866,
        699.4027,
        700.2187,
        701.0347,
        701.8505,
        702.6664,
        703.4821,
        704.2978,
        705.1134,
        705.9289,
        706.7444,
        707.5598,
        708.3751,
        709.1904,
        710.0056,
        710.8207,
        711.6358,
        712.4508,
        713.2657,
        714.0806,
        714.8954,
        715.7101,
        716.5247,
        717.3393,
        718.1538,
        718.9683,
        719.7827,
        720.597,
        721.4112,
        722.2254,
        723.0395,
        723.8535,
        724.6675,
        725.4814,
        726.2952,
        727.109,
        727.9227,
        728.7363,
        729.5498,
        730.3633,
        731.1767,
        731.9901,
        732.8034,
        733.6166,
        734.4297,
        735.2428,
        736.0558,
        736.8687,
        737.6816,
        738.4944,
        739.3071,
        740.1198,
        740.9324,
        741.7449,
        742.5573,
        743.3697,
        744.182,
        744.9942,
        745.8064,
        746.6185,
        747.4305,
        748.2425,
        749.0544,
        749.8662,
        750.678,
        751.4896,
        752.3013,
        753.1128,
        753.9243,
        754.7357,
        755.547,
        756.3583,
        757.1695,
        757.9806,
        758.7917,
        759.6027,
        760.4136,
        761.2244,
        762.0352,
        762.8459,
        763.6566,
        764.4671,
        765.2776,
        766.0881,
        766.8984,
        767.7087,
        768.5189,
        769.3291,
        770.1392,
        770.9492,
        771.7591,
        772.569,
        773.3788,
        774.1886,
        774.9982,
        775.8078,
        776.6173,
        777.4268,
        778.2362,
        779.0455,
        779.8548,
        780.6639,
        781.4731,
        782.2821,
        783.0911,
        783.9,
        784.7088,
        785.5176,
        786.3263,
        787.1349,
        787.9434,
        788.7519,
        789.5604,
        790.3687,
        791.177,
        791.9852,
        792.7933,
        793.6014,
        794.4094,
        795.2173,
        796.0252,
        796.833,
        797.6407,
        798.4484,
        799.256,
        800.0635,
        800.8709,
        801.6783,
        802.4856,
        803.2929,
        804.1001,
        804.9072,
        805.7142,
        806.5212,
        807.3281,
        808.1349,
        808.9417,
        809.7484,
        810.555,
        811.3615,
        812.168,
        812.9745,
        813.7808,
        814.5871,
        815.3933,
        816.1994,
        817.0055,
        817.8115,
        818.6175,
        819.4234,
        820.2292,
        821.0349,
        821.8406,
        822.6462,
        823.4517,
        824.2572,
        825.0626,
        825.8679,
        826.6732,
        827.4784,
        828.2835,
        829.0886,
        829.8936,
        830.6985,
        831.5033,
        832.3081,
        833.1129,
        833.9175,
        834.7221,
        835.5266,
        836.3311,
        837.1355,
        837.9398,
        838.7441,
        839.5483,
        840.3524,
        841.1564,
        841.9604,
        842.7643,
        843.5682,
        844.372,
        845.1757,
        845.9794,
        846.783,
        847.5865,
        848.3899,
        849.1933,
        849.9967,
        850.7999,
        851.6031,
        852.4062,
        853.2093,
        854.0123,
        854.8152,
        855.6181,
        856.4209,
        857.2236,
        858.0263,
        858.8289,
        859.6315,
        860.4339,
        861.2363,
        862.0387,
        862.841,
        863.6432,
        864.4453,
        865.2474,
        866.0494,
        866.8514,
        867.6533,
        868.4551,
        869.2569,
        870.0586,
        870.8602,
        871.6618,
        872.4633,
        873.2648,
        874.0662,
        874.8675,
        875.6687,
        876.4699,
        877.2711,
        878.0721,
        878.8731,
        879.6741,
        880.475,
        881.2758,
        882.0765,
        882.8772,
        883.6778,
        884.4784,
        885.2789,
        886.0793,
        886.8797,
        887.68,
        888.4803,
        889.2805,
        890.0806,
        890.8807,
        891.6807,
        892.4806,
        893.2805,
        894.0803,
        894.8801,
        895.6798,
        896.4795,
        897.279,
        898.0786,
        898.878,
        899.6774,
        900.4768,
        901.276,
        902.0753,
        902.8744,
        903.6735,
        904.4726,
        905.2715,
        906.0705,
        906.8693,
        907.6681,
        908.4669,
        909.2655,
        910.0642,
        910.8627,
        911.6612,
        912.4597,
        913.2581,
        914.0564,
        914.8547,
        915.6529,
        916.4511,
        917.2491,
        918.0472,
        918.8452,
        919.6431,
        920.441,
        921.2388,
        922.0365,
        922.8342,
        923.6319,
        924.4295,
        925.227,
        926.0245,
        926.8219,
        927.6192,
        928.4165,
        929.2138,
        930.011,
        930.8081,
        931.6052,
        932.4022,
        933.1992,
        933.9961,
        934.793,
        935.5898,
        936.3865,
        937.1832,
        937.9798,
        938.7764,
        939.573,
        940.5484,
        942.5546,
        944.5567,
        946.5547,
        948.5485,
        950.5382,
        952.5239,
        954.5054,
        956.483,
        958.4565,
        960.426,
        962.3916,
        964.3532,
        966.3108,
        968.2646,
        970.2144,
        972.1604,
        974.1026,
        976.0409,
        977.9755,
        979.9062,
        981.8332,
        983.7565,
        985.676,
        987.5919,
        989.504,
        991.4126,
        993.3174,
        995.2187,
        997.1164,
        999.0104,
        1000.901,
        1002.788,
        1004.6715,
        1006.5515,
        1008.428,
        1010.3011,
        1012.1707,
        1014.0369,
        1015.8997,
        1017.7592,
        1019.6153,
        1021.468,
        1023.3175,
        1025.1636,
        1027.0065,
        1028.8461,
        1030.6825,
        1032.5156,
        1034.3456,
        1036.1723,
        1037.9959,
        1039.8164,
        1041.6337,
        1043.4479,
        1045.259,
        1047.067,
        1048.872,
        1050.674,
        1052.4729,
        1054.2688,
        1056.0618,
        1057.8518,
        1059.6388,
        1061.4229,
        1063.2041,
        1064.9824,
        1066.7579,
        1068.5304,
        1070.3002,
        1072.0671,
        1073.8312,
        1075.5925,
        1077.351,
        1079.1068,
        1080.8598,
        1082.6101,
        1084.3577,
        1086.1026,
        1087.8449,
        1089.5845,
        1091.3214,
        1093.0557,
        1094.7874,
        1096.5166,
        1098.2431,
        1099.9671,
        1101.6885,
        1103.4074,
        1105.1238,
        1106.8377,
        1108.5492,
        1110.2581,
        1111.9646,
        1113.6687,
        1115.3703,
        1117.0696,
        1118.7664,
        1120.4609,
        1122.153,
        1123.8428,
        1125.5303,
        1127.2154,
        1128.8982,
        1130.5788,
        1132.2571,
        1133.9331,
        1135.6069,
        1137.2784,
        1138.9478,
        1140.6149,
        1142.2799,
        1143.9427,
        1145.6033,
        1147.2618,
        1148.9181,
        1150.5723,
        1152.2245,
        1153.8745,
        1155.5225,
        1157.1684,
        1158.8122,
        1160.4541,
        1162.0939,
        1163.7316,
        1165.3674,
        1167.0013,
        1168.6331,
        1170.263,
        1171.8909,
        1173.5169,
        1175.1409,
        1176.7631,
        1178.3834,
        1180.0018,
        1181.6183,
        1183.2329,
        1184.8457,
        1186.4567,
        1188.0659,
        1189.6732,
        1191.2787,
        1192.8825,
        1194.4844,
        1196.0847,
        1197.6831,
        1199.2798,
        1200.8748,
        1202.468,
        1204.0596,
        1205.6494,
        1207.2376,
        1208.8241,
        1210.4089,
        1211.9921,
        1213.5736,
        1215.1535,
        1216.7317,
        1218.3084,
        1219.8834,
        1221.4569,
        1223.0287,
        1224.599,
        1226.1678,
        1227.7349,
        1229.3006,
        1230.8647,
        1232.4273,
        1233.9884,
        1235.5479,
        1237.106,
        1238.6626,
        1240.2177,
        1241.7713,
        1243.3235,
        1244.8743,
        1246.4236,
        1247.9715,
        1249.5179,
        1251.063,
        1252.6066,
        1254.1488,
        1255.6897,
        1257.2292,
        1258.7673,
        1260.304,
        1261.8394,
        1263.3735,
        1264.9062,
        1266.4376,
        1267.9676,
        1269.4964,
        1271.0238,
        1272.55,
        1274.0748,
        1275.5984,
        1277.1207,
        1278.6417,
        1280.1615,
        1281.68,
        1283.1973,
        1284.7133,
        1286.2281,
        1287.7417,
        1289.254,
        1290.7652,
        1292.2751,
        1293.7838,
        1295.2914,
        1296.7977,
        1298.3029,
        1299.8069,
        1301.3098,
        1302.8115,
        1304.312,
        1305.8114,
        1307.3096,
        1308.8067,
        1310.3027,
        1311.7975,
        1313.2913,
        1314.7839,
        1316.2754,
        1317.7658,
        1319.2551,
        1320.7433,
        1322.2304,
        1323.7165,
        1325.2014,
        1326.6853,
        1328.1681,
        1329.6499,
        1331.1306,
        1332.6102,
        1334.0889,
        1335.5664,
        1337.0429,
        1338.5184,
        1339.9928,
        1341.4662,
        1342.9386,
        1344.41,
        1345.8804,
        1347.3497,
        1348.8181,
        1350.2854,
        1351.7517,
        1353.217,
        1354.6814,
        1356.1447,
        1357.6071,
        1359.0685,
        1360.5289,
        1361.9883,
        1363.4467,
        1364.9042,
        1366.3607,
        1367.8162,
        1369.2708,
        1370.7244,
        1372.177,
        1373.6287,
        1375.0794,
        1376.5292,
        1377.9781,
        1379.4259,
        1380.8729,
        1382.3189,
        1383.7639,
        1385.208,
        1386.6512,
        1388.0934,
        1389.5347,
        1390.9751,
        1392.4145,
        1393.853,
        1395.2906,
        1396.7273,
        1398.163,
        1399.5978,
        1401.0316,
        1402.4646,
        1403.8966,
        1405.3277,
        1406.7578,
        1408.1871,
        1409.6154,
        1411.0428,
        1412.4693,
        1413.8949,
        1415.3195,
        1416.7432,
        1418.166,
        1419.5879,
        1421.0089,
        1422.4289,
        1423.8481,
        1425.2662,
        1426.6835,
        1428.0999,
        1429.5153,
        1430.9298,
        1432.3434,
        1433.756,
        1435.1678,
        1436.5786,
        1437.9885,
        1439.3974,
        1440.8054,
        1442.2125,
        1443.6187,
        1445.0239,
        1446.4281,
        1447.8315,
        1449.2339,
        1450.6354,
        1452.0359,
        1453.4354,
        1454.8341,
        1456.2317,
        1457.6285,
        1459.0242,
        1460.419,
        1461.8129,
        1463.2058,
        1464.5977,
        1465.9887,
        1467.3787,
        1468.7677,
        1470.1558,
        1471.5428,
        1472.9289,
        1474.314,
        1475.6982,
        1477.0813,
        1478.4634,
        1479.8446,
        1481.2247,
        1482.6039,
        1483.982,
        1485.3591,
        1486.7352,
        1488.1103,
        1489.4844,
        1490.8574,
        1492.2295,
        1493.6004,
        1494.9704,
        1496.3393,
        1497.7071,
        1499.0739,
        1500.4397,
        1501.8043,
        1503.1679,
        1504.5305,
        1505.8919,
        1507.2523,
        1508.6116,
        1509.9698,
        1511.3269,
        1512.683,
        1514.0379,
        1515.3917,
        1516.7443,
        1518.0959,
        1519.4463,
        1520.7956,
        1522.1437,
        1523.4907,
        1524.8366,
        1526.1813,
        1527.5248,
        1528.8672,
        1530.2084,
        1531.5484,
        1532.8872,
        1534.2248,
        1535.5612,
        1536.8964,
        1538.2304,
        1539.5631,
        1540.8947,
        1542.225,
        1543.554,
        1544.8818,
        1546.2084,
        1547.5337,
        1548.8577,
        1550.1804,
        1551.5019,
        1552.822,
        1554.1409,
        1555.4584,
        1556.7746,
        1558.0895,
        1559.403,
        1560.7153,
        1562.0261,
        1563.3356,
        1564.6438,
        1565.9505,
        1567.2559,
        1568.5599,
        1569.8625,
        1571.1637,
        1572.4634,
        1573.7618,
        1575.0587,
        1576.3541,
        1577.6481,
        1578.9407,
        1580.2317,
        1581.5213,
        1582.8094,
        1584.096,
        1585.3811,
        1586.6647,
        1587.9467,
        1589.2272,
        1590.5062,
        1591.7836,
        1593.0594,
        1594.3336,
        1595.6063,
        1596.8773,
        1598.1468,
        1599.4146,
        1600.6808,
        1601.9454,
        1603.2083,
        1604.4696,
        1605.7291,
        1606.987,
        1608.2432,
        1609.4977,
        1610.7505,
        1612.0015,
        1613.2508,
        1614.4984,
        1615.7442,
        1616.9882,
        1618.2305,
        1619.4709,
        1620.7096,
        1621.9464,
        1623.1814,
        1624.4145,
        1625.6458,
        1626.8753,
        1628.1028,
        1629.3284,
        1630.5522,
        1631.774,
        1632.9939,
        1634.2119,
        1635.4279,
        1636.6419,
        1637.854,
        1639.0641,
        1640.2722,
        1641.4782,
        1642.6822,
        1643.8842,
        1645.0841,
        1646.282,
        1647.4777,
        1648.6714,
        1649.8629,
        1651.0524,
        1652.2396,
        1653.4248,
        1654.6077,
        1655.7885,
        1656.9671,
        1658.1435,
        1659.3177,
        1660.4896,
        1661.6593,
        1662.8267,
        1663.9918,
        1665.1547,
        1666.3152,
        1667.4734,
        1668.6293,
        1669.7828,
        1670.9339,
        1672.0827,
        1673.2291,
        1674.373,
        1675.5145,
        1676.6536,
        1677.7902,
        1678.9244,
        1680.056,
        1681.1852,
        1682.3118,
        1683.4359,
        1684.5574,
        1685.6763,
        1686.7927,
        1687.9065,
        1689.0177,
        1690.1262,
        1691.232,
        1692.3352,
        1693.4358,
        1694.5336,
        1695.6287,
        1696.7211,
        1697.8107,
    ]
)

E_W_per_m2_nm_sim_NIST = numpy.array(
    [
        0,
        -0.0005,
        0.0037,
        0.0031,
        0.0016,
        0.0029,
        -0.0043,
        0,
        0.0098,
        0.0049,
        -0.0037,
        0.0025,
        -0.0071,
        -0.0016,
        0,
        0.0038,
        0.0084,
        0,
        0.0015,
        0,
        0.0023,
        0,
        -0.0036,
        0.0167,
        0.0024,
        -0.0037,
        -0.0082,
        -0.0105,
        -0.0046,
        0.0043,
        0,
        0.0029,
        0,
        -0.0057,
        0.0121,
        -0.0088,
        -0.0025,
        -0.0053,
        0,
        0,
        0.0045,
        0,
        -0.0198,
        0.0082,
        0.002,
        0.003,
        0.0014,
        0.0025,
        -0.0087,
        0,
        0.0061,
        -0.0014,
        -0.0103,
        -0.0043,
        -0.003,
        -0.0065,
        0.0045,
        -0.0011,
        -0.0029,
        0.0037,
        -0.0084,
        -0.0033,
        0.0012,
        0,
        0.0025,
        -0.0065,
        0,
        0.0034,
        0,
        0.0011,
        0.0023,
        0.0026,
        -0.0068,
        -0.0035,
        -0.0035,
        0.0013,
        -0.006,
        0.0033,
        -0.0034,
        0.0023,
        0.0026,
        0,
        0,
        -0.0026,
        -0.0039,
        0.0053,
        0.0053,
        0,
        0.0038,
        0,
        -0.0039,
        0,
        0.0013,
        0,
        0.0024,
        -0.0062,
        0,
        -0.0036,
        0.0012,
        0,
        0,
        -0.0044,
        -0.0032,
        0.0021,
        -0.0054,
        0.002,
        0.0041,
        0.0019,
        0,
        0.0046,
        0,
        0.0018,
        0.0051,
        0.0042,
        0.0083,
        0.0025,
        0.0008,
        0.0101,
        0.0095,
        0.0125,
        0.0144,
        0.0309,
        0.0368,
        0.0548,
        0.0695,
        0.0907,
        0.1183,
        0.1433,
        0.1734,
        0.2031,
        0.2362,
        0.2807,
        0.305,
        0.3342,
        0.3717,
        0.3743,
        0.387,
        0.3775,
        0.4091,
        0.4211,
        0.4437,
        0.4721,
        0.5008,
        0.5518,
        0.5775,
        0.5874,
        0.5755,
        0.5767,
        0.5818,
        0.5964,
        0.6306,
        0.644,
        0.6431,
        0.6532,
        0.6773,
        0.7089,
        0.742,
        0.7847,
        0.8166,
        0.8394,
        0.8517,
        0.8416,
        0.8418,
        0.8169,
        0.8167,
        0.8369,
        0.8636,
        0.8805,
        0.8754,
        0.8575,
        0.8549,
        0.8207,
        0.8148,
        0.7841,
        0.7423,
        0.6843,
        0.6476,
        0.6068,
        0.5759,
        0.5684,
        0.5828,
        0.6137,
        0.6496,
        0.7116,
        0.7721,
        0.8517,
        0.9134,
        0.9965,
        1.0818,
        1.1599,
        1.2181,
        1.2815,
        1.3106,
        1.3179,
        1.3126,
        1.2922,
        1.2712,
        1.2293,
        1.1783,
        1.1464,
        1.1107,
        1.0766,
        1.0543,
        1.0418,
        1.0445,
        1.0368,
        1.0317,
        1.0344,
        1.0438,
        1.0612,
        1.0829,
        1.0972,
        1.1021,
        1.0988,
        1.0808,
        1.0631,
        1.033,
        1.0067,
        0.9918,
        1.0046,
        1.0117,
        1.0346,
        1.0684,
        1.1136,
        1.1582,
        1.2111,
        1.2565,
        1.2956,
        1.3211,
        1.3249,
        1.3366,
        1.3524,
        1.3495,
        1.3424,
        1.323,
        1.312,
        1.2925,
        1.2693,
        1.2745,
        1.3111,
        1.3719,
        1.4074,
        1.3899,
        1.3561,
        1.3358,
        1.3116,
        1.3088,
        1.3305,
        1.3717,
        1.4206,
        1.4673,
        1.4948,
        1.505,
        1.5309,
        1.5777,
        1.6307,
        1.6665,
        1.6674,
        1.645,
        1.6635,
        1.7458,
        1.878,
        1.9778,
        1.9809,
        1.8846,
        1.7722,
        1.7033,
        1.6676,
        1.6652,
        1.6455,
        1.5634,
        1.44,
        1.3433,
        1.2901,
        1.2714,
        1.275,
        1.3062,
        1.3593,
        1.4053,
        1.4354,
        1.4286,
        1.4034,
        1.3572,
        1.3126,
        1.2605,
        1.2289,
        1.2031,
        1.1866,
        1.1928,
        1.2081,
        1.2425,
        1.279,
        1.2967,
        1.2758,
        1.2487,
        1.2045,
        1.1842,
        1.1761,
        1.1664,
        1.1713,
        1.1777,
        1.1841,
        1.1892,
        1.2081,
        1.2208,
        1.241,
        1.2532,
        1.274,
        1.2947,
        1.3089,
        1.3344,
        1.3529,
        1.3793,
        1.4019,
        1.4244,
        1.4473,
        1.4634,
        1.4737,
        1.4869,
        1.492,
        1.492,
        1.4875,
        1.4816,
        1.4756,
        1.4711,
        1.4647,
        1.4588,
        1.4539,
        1.4514,
        1.4568,
        1.4582,
        1.4664,
        1.4732,
        1.4838,
        1.4983,
        1.5068,
        1.5188,
        1.5288,
        1.5321,
        1.5397,
        1.5434,
        1.5482,
        1.5501,
        1.5461,
        1.5472,
        1.5384,
        1.5381,
        1.5357,
        1.5332,
        1.5315,
        1.5364,
        1.5398,
        1.5398,
        1.5451,
        1.5462,
        1.55,
        1.549,
        1.553,
        1.5573,
        1.5571,
        1.5582,
        1.5555,
        1.5548,
        1.5521,
        1.5455,
        1.5396,
        1.5292,
        1.5229,
        1.506,
        1.493,
        1.4819,
        1.473,
        1.4598,
        1.4551,
        1.4532,
        1.4482,
        1.4477,
        1.4543,
        1.4618,
        1.4696,
        1.4846,
        1.4962,
        1.5197,
        1.5388,
        1.5584,
        1.5764,
        1.5995,
        1.6205,
        1.6279,
        1.6351,
        1.6416,
        1.6378,
        1.6348,
        1.6225,
        1.6126,
        1.6006,
        1.5809,
        1.561,
        1.5347,
        1.5192,
        1.4997,
        1.481,
        1.4676,
        1.4544,
        1.442,
        1.4242,
        1.4133,
        1.4086,
        1.3913,
        1.3781,
        1.373,
        1.3573,
        1.3474,
        1.3346,
        1.32,
        1.3063,
        1.2978,
        1.2859,
        1.2818,
        1.2742,
        1.268,
        1.2637,
        1.2677,
        1.2681,
        1.2696,
        1.2685,
        1.28,
        1.2807,
        1.2806,
        1.2899,
        1.2948,
        1.2971,
        1.3,
        1.31,
        1.3119,
        1.3217,
        1.335,
        1.3356,
        1.3462,
        1.3566,
        1.3708,
        1.3827,
        1.3964,
        1.4144,
        1.4256,
        1.441,
        1.4494,
        1.4593,
        1.4635,
        1.4612,
        1.468,
        1.4589,
        1.45,
        1.4377,
        1.4302,
        1.4215,
        1.4124,
        1.4049,
        1.3996,
        1.3887,
        1.3818,
        1.3692,
        1.3598,
        1.3477,
        1.3349,
        1.335,
        1.3236,
        1.326,
        1.3113,
        1.3129,
        1.3055,
        1.3112,
        1.312,
        1.3193,
        1.3226,
        1.3357,
        1.3431,
        1.3588,
        1.3761,
        1.3918,
        1.4109,
        1.4176,
        1.4193,
        1.4086,
        1.3978,
        1.3894,
        1.3752,
        1.3592,
        1.3565,
        1.3455,
        1.3486,
        1.3433,
        1.3406,
        1.3437,
        1.3359,
        1.339,
        1.3337,
        1.3344,
        1.3399,
        1.3366,
        1.3423,
        1.3427,
        1.3459,
        1.35,
        1.3491,
        1.3495,
        1.3435,
        1.3432,
        1.3383,
        1.3382,
        1.3471,
        1.3455,
        1.3414,
        1.3464,
        1.3354,
        1.3371,
        1.3341,
        1.3307,
        1.3318,
        1.3338,
        1.3531,
        1.386,
        1.4224,
        1.4517,
        1.4732,
        1.4689,
        1.4544,
        1.4424,
        1.4424,
        1.451,
        1.4391,
        1.4247,
        1.396,
        1.3565,
        1.312,
        1.2752,
        1.2482,
        1.2158,
        1.2037,
        1.1867,
        1.1775,
        1.1769,
        1.1722,
        1.169,
        1.1669,
        1.1679,
        1.1655,
        1.1669,
        1.1732,
        1.1751,
        1.193,
        1.2095,
        1.2365,
        1.2605,
        1.3033,
        1.3418,
        1.389,
        1.4271,
        1.4561,
        1.4663,
        1.4637,
        1.4376,
        1.4,
        1.359,
        1.3237,
        1.2905,
        1.2573,
        1.229,
        1.1988,
        1.1819,
        1.1625,
        1.1529,
        1.1494,
        1.1472,
        1.1578,
        1.1822,
        1.2018,
        1.2378,
        1.2661,
        1.3034,
        1.3327,
        1.3631,
        1.4043,
        1.4487,
        1.4697,
        1.4581,
        1.4238,
        1.37,
        1.3159,
        1.2826,
        1.2895,
        1.2997,
        1.3241,
        1.3338,
        1.3454,
        1.3232,
        1.3078,
        1.279,
        1.2436,
        1.2208,
        1.1962,
        1.1884,
        1.1903,
        1.2001,
        1.2166,
        1.2301,
        1.2269,
        1.2305,
        1.2118,
        1.2093,
        1.1947,
        1.1803,
        1.1716,
        1.1626,
        1.1556,
        1.1631,
        1.1837,
        1.2111,
        1.241,
        1.2823,
        1.3889,
        1.5997,
        1.9081,
        2.1123,
        2.0376,
        1.7469,
        1.4671,
        1.2594,
        1.1355,
        1.0574,
        1.021,
        0.9765,
        0.9565,
        0.9351,
        0.9107,
        0.8935,
        0.8717,
        0.8517,
        0.8372,
        0.8252,
        0.808,
        0.8056,
        0.7993,
        0.8039,
        0.8103,
        0.8014,
        0.7967,
        0.7882,
        0.7805,
        0.7789,
        0.7824,
        0.813,
        0.8733,
        0.9674,
        1.0086,
        1.0109,
        0.9577,
        0.9104,
        0.8731,
        0.8481,
        0.854,
        0.8773,
        0.9352,
        0.9872,
        1.009,
        0.9988,
        0.9769,
        0.9504,
        0.9111,
        0.8745,
        0.8276,
        0.808,
        0.7695,
        0.7644,
        0.7422,
        0.7383,
        0.7182,
        0.7033,
        0.668,
        0.6364,
        0.6033,
        0.5732,
        0.5471,
        0.5124,
        0.4934,
        0.4873,
        0.4767,
        0.4843,
        0.4904,
        0.513,
        0.5565,
        0.6587,
        0.8386,
        1.1486,
        1.6774,
        2.2769,
        2.6203,
        2.4716,
        2.086,
        1.8029,
        1.8031,
        1.949,
        1.9039,
        1.5865,
        1.2007,
        0.9244,
        0.7896,
        0.7952,
        0.994,
        1.2905,
        1.4581,
        1.3369,
        1.0573,
        0.8324,
        0.6614,
        0.5915,
        0.6052,
        0.7105,
        0.7289,
        0.6694,
        0.5283,
        0.4179,
        0.3447,
        0.314,
        0.2873,
        0.2735,
        0.243,
        0.2404,
        0.2214,
        0.2256,
        0.2179,
        0.2197,
        0.2211,
        0.2175,
        0.205,
        0.204,
        0.2179,
        0.2151,
        0.2238,
        0.2226,
        0.2253,
        0.2349,
        0.2281,
        0.2411,
        0.2322,
        0.2366,
        0.2583,
        0.2723,
        0.2931,
        0.299,
        0.3125,
        0.3345,
        0.33,
        0.3329,
        0.351,
        0.3706,
        0.397,
        0.403,
        0.4175,
        0.4409,
        0.451,
        0.4786,
        0.5014,
        0.5305,
        0.6082,
        0.7775,
        1.015,
        1.3236,
        1.6408,
        1.8375,
        1.8466,
        1.6876,
        1.4961,
        1.2494,
        1.0704,
        0.9335,
        0.8509,
        0.7743,
        0.7273,
        0.7156,
        0.7244,
        0.8226,
        0.9694,
        1.2003,
        1.4763,
        1.7644,
        1.9043,
        1.8305,
        1.5755,
        1.2945,
        1.1323,
        0.977,
        0.8901,
        0.8785,
        0.9525,
        1.109,
        1.2739,
        1.4372,
        1.4349,
        1.2528,
        0.9725,
        0.7121,
        0.5384,
        0.4,
        0.3162,
        0.304,
        0.2708,
        0.2828,
        0.2996,
        0.3452,
        0.4117,
        0.4678,
        0.5059,
        0.4623,
        0.4138,
        0.3369,
        0.2813,
        0.2168,
        0.2002,
        0.1448,
        0.0873,
        0.1344,
        0.0798,
        0.0925,
        0.082,
        0.0918,
        0.0855,
        0.0764,
        0.0718,
        0.0809,
        0.1039,
        0.072,
        0.0524,
        0.096,
        0.1285,
        0.0831,
        0.0504,
        0.0796,
        0.1551,
        0.1025,
        0.1619,
        0.0548,
        0.1291,
        0.1383,
        0.1458,
        0.1587,
        0.16,
        0.1574,
        0.1484,
        0.1529,
        0.1654,
        0.1927,
        0.2244,
        0.2784,
        0.3453,
        0.437,
        0.514,
        0.5895,
        0.6587,
        0.7934,
        0.9687,
        1.0103,
        0.8773,
        0.6728,
        0.5934,
        0.7028,
        0.9153,
        1.1767,
        1.2221,
        1.0251,
        0.7224,
        0.559,
        0.5264,
        0.5624,
        0.6171,
        0.7029,
        0.829,
        1.0091,
        1.1319,
        1.1174,
        0.9818,
        0.8292,
        0.7268,
        0.6651,
        0.6319,
        0.6164,
        0.6129,
        0.6196,
        0.6282,
        0.6448,
        0.6466,
        0.6294,
        0.5995,
        0.5845,
        0.5824,
        0.5974,
        0.6248,
        0.6783,
        0.7409,
        0.8385,
        0.9313,
        0.9618,
        0.9066,
        0.7942,
        0.6984,
        0.6452,
        0.6043,
        0.5789,
        0.559,
        0.5609,
        0.5738,
        0.5963,
        0.6114,
        0.6321,
        0.6536,
        0.6793,
        0.7352,
        0.8925,
        1.1554,
        1.1966,
        1.0857,
        0.8929,
        0.8307,
        0.7903,
        0.6911,
        0.5459,
        0.4564,
        0.415,
        0.3905,
        0.3835,
        0.3936,
        0.4349,
        0.5047,
        0.592,
        0.632,
        0.6049,
        0.5221,
        0.4263,
        0.3461,
        0.2852,
        0.2394,
        0.2111,
        0.1886,
        0.1741,
        0.1635,
        0.1572,
        0.1532,
        0.1507,
        0.1473,
        0.1475,
        0.1453,
        0.148,
        0.1505,
        0.1551,
        0.1579,
        0.1626,
        0.1648,
        0.1706,
        0.1733,
        0.1793,
        0.1831,
        0.1922,
        0.2015,
        0.2171,
        0.2342,
        0.2571,
        0.2756,
        0.2983,
        0.3219,
        0.3693,
        0.4469,
        0.5798,
        0.7376,
        0.8481,
        0.8702,
        0.8132,
        0.7294,
        0.6606,
        0.6073,
        0.5725,
        0.5448,
        0.5162,
        0.4775,
        0.4446,
        0.4153,
        0.3957,
        0.3772,
        0.3688,
        0.3627,
        0.358,
        0.3572,
        0.3606,
        0.3632,
        0.3738,
        0.3831,
        0.3976,
        0.4108,
        0.4191,
        0.4285,
        0.4371,
        0.4518,
        0.4727,
        0.5077,
        0.5527,
        0.5845,
        0.5988,
        0.5826,
        0.5584,
        0.5302,
        0.5106,
        0.4918,
        0.4801,
        0.4673,
        0.4613,
        0.456,
        0.4531,
        0.4469,
        0.4464,
        0.4481,
        0.4496,
        0.455,
        0.4595,
        0.4613,
        0.4668,
        0.482,
        0.5247,
        0.6157,
        0.8214,
        1.0682,
        1.233,
        1.2405,
        1.0825,
        0.885,
        0.7166,
        0.5978,
        0.5134,
        0.4542,
        0.413,
        0.3807,
        0.3548,
        0.3337,
        0.3168,
        0.3016,
        0.2913,
        0.2796,
        0.2692,
        0.2621,
        0.254,
        0.2459,
        0.2415,
        0.2356,
        0.2305,
        0.2271,
        0.223,
        0.22,
        0.2186,
        0.2159,
        0.2142,
        0.2128,
        0.2147,
        0.2143,
        0.2154,
        0.2181,
        0.2208,
        0.2233,
        0.2288,
        0.233,
        0.238,
        0.2437,
        0.2523,
        0.2585,
        0.2665,
        0.2763,
        0.2841,
        0.2918,
        0.302,
        0.3093,
        0.3162,
        0.3207,
        0.3257,
        0.3251,
        0.322,
        0.3162,
        0.3088,
        0.297,
        0.2863,
        0.2718,
        0.2586,
        0.2432,
        0.2283,
        0.2145,
        0.2028,
        0.1909,
        0.178,
        0.1695,
        0.1725,
        0.1966,
        0.232,
        0.2567,
        0.2539,
        0.2223,
        0.1776,
        0.1397,
        0.112,
        0.0916,
        0.0759,
        0.0643,
        0.0547,
        0.0472,
        0.0425,
        0.0395,
        0.0367,
        0.035,
        0.0328,
        0.0314,
        0.03,
        0.0277,
        0.0264,
        0.0253,
        0.0244,
        0.0238,
        0.0225,
        0.022,
        0.0223,
        0.0218,
        0.0215,
        0.0211,
        0.0219,
        0.0228,
        0.0234,
        0.0263,
        0.0305,
        0.0339,
        0.0362,
        0.0362,
        0.0353,
        0.0352,
        0.0361,
        0.037,
        0.0368,
        0.0354,
        0.0328,
        0.0304,
        0.0285,
        0.0277,
        0.0265,
        0.0276,
        0.0279,
        0.0288,
        0.0283,
        0.0278,
        0.0267,
        0.0255,
        0.0248,
        0.0242,
        0.0239,
        0.0235,
        0.0233,
        0.0241,
        0.0238,
        0.0247,
        0.0247,
        0.0254,
        0.0261,
        0.027,
        0.0283,
        0.0297,
        0.0319,
        0.034,
        0.0371,
        0.0426,
        0.0525,
        0.0712,
        0.1014,
        0.1314,
        0.1523,
        0.1571,
        0.1448,
        0.127,
        0.1112,
        0.0992,
        0.0904,
        0.0845,
        0.0792,
        0.077,
        0.0751,
        0.0745,
        0.0749,
        0.0769,
        0.0789,
        0.0821,
        0.0854,
        0.0901,
        0.093,
        0.0974,
        0.1012,
        0.1044,
        0.1075,
        0.1108,
        0.1138,
        0.1187,
        0.1218,
        0.1255,
        0.1282,
        0.1333,
        0.1365,
        0.1419,
        0.1466,
        0.1514,
        0.1575,
        0.1642,
        0.1706,
        0.176,
        0.1817,
        0.1888,
        0.1945,
        0.2003,
        0.2063,
        0.2141,
        0.2222,
        0.2328,
        0.2489,
        0.2778,
        0.3323,
        0.4119,
        0.4959,
        0.5584,
        0.5741,
        0.5463,
        0.4945,
        0.4437,
        0.4003,
        0.3679,
        0.3406,
        0.3194,
        0.3027,
        0.2915,
        0.2813,
        0.2728,
        0.2652,
        0.261,
        0.255,
        0.2522,
        0.2476,
        0.2449,
        0.2421,
        0.2401,
        0.2376,
        0.2374,
        0.2352,
        0.2342,
        0.234,
        0.2338,
        0.2322,
        0.2331,
        0.2319,
        0.2326,
        0.2315,
        0.2327,
        0.2334,
        0.2337,
        0.2344,
        0.2365,
        0.2361,
        0.2375,
        0.2381,
        0.2421,
        0.2427,
        0.2477,
        0.2518,
        0.2614,
        0.2729,
        0.2962,
        0.3308,
        0.3632,
        0.3817,
        0.3873,
        0.3687,
        0.3473,
        0.3217,
        0.3033,
        0.2859,
        0.2744,
        0.263,
        0.2563,
        0.2478,
        0.2427,
        0.2378,
        0.2346,
        0.2294,
        0.2292,
        0.2247,
        0.2231,
        0.2202,
        0.2213,
        0.2173,
        0.217,
        0.2145,
        0.2147,
        0.2115,
        0.2109,
        0.2091,
        0.2101,
        0.2075,
        0.2088,
        0.2065,
        0.2069,
        0.2049,
        0.2053,
        0.2038,
        0.2054,
        0.2043,
        0.2063,
        0.2043,
        0.2059,
        0.2057,
        0.2081,
        0.208,
        0.2107,
        0.2105,
        0.2132,
        0.2146,
        0.2187,
        0.2217,
        0.2299,
        0.2405,
        0.2606,
        0.2856,
        0.3222,
        0.353,
        0.3767,
        0.3831,
        0.3779,
        0.3603,
        0.347,
        0.3301,
        0.3159,
        0.293,
        0.2771,
        0.2609,
        0.253,
        0.2417,
        0.2321,
        0.2276,
        0.2269,
        0.2165,
        0.2207,
        0.214,
        0.2091,
        0.2042,
        0.2032,
        0.212,
    ]
)
# Must clip negative numbers to zero for a valid SI.
E_sim_NIST = computation.SpectralIrradiance(
    lambda_nm=lambda_nm_sim_NIST,
    E_W_per_m2_nm=numpy.clip(E_W_per_m2_nm_sim_NIST, 0.0, None),
)
